searchData={"items":[{"type":"module","title":"DNS","doc":"Documentation for `DNS`.\n\nAll DNS related modules are namespaced under this module.\nDNS resources are implemented with protocols `String.Chars` and `DNS.Parameter`.\n\n- `to_string/1` is implemented for all DNS resources to show human readable data information.\n\n- `to_iodata/1` is implemented for all DNS resources in dns protocol data.","ref":"DNS.html"},{"type":"function","title":"DNS.to_iodata/1","doc":"","ref":"DNS.html#to_iodata/1"},{"type":"module","title":"DNS.Class","doc":"# DNS Class\n\n# Note\nAs noted in [RFC6762], Multicast DNS can only carry DNS records with classes in the range 0-32767.\nClasses in the range 32768 to 65535 are incompatible with Multicast DNS. But Multicast DNS uses the\n32768(0x8000) as a special value to indicate a cache-flush request.\n\n# Note\nWhen this registry is modified, the YANG module [iana-dns-class-rr-type]\nmust be updated as defined in [RFC9108].\n\n    Decimal \tHex \tRegistration Procedures \tNote\n    0\t0x0000\tStandards Action\n    1-127\t0x0000-0x007F\tIETF Review\tdata CLASSes only\n    128-253\t0x0080-0x00FD\tIETF Review\tQCLASSes and meta-CLASSes only\n    256-32767\t0x0100-0x7FFF\tIETF Review\n    32768-57343\t0x8000-0xDFFF\tSpecification Required\tdata CLASSes only\n    57344-65279\t0xE000-0xFEFF\tSpecification Required\tQCLASSes and meta-CLASSes only\n    65280-65534\t0xFF00-0xFFFE\tPrivate Use\n    65535\t0xFFFF\tStandards Action\n\n    Decimal \tHexadecimal \tName \tReference\n    0\t0x0000\tReserved\t[RFC6895]\n    1\t0x0001\tInternet (IN)\t[RFC1035]\n    2\t0x0002\tUnassigned\n    3\t0x0003\tChaos (CH)\t[D. Moon, \"Chaosnet\", A.I. Memo 628, Massachusetts Institute of Technology Artificial Intelligence Laboratory, June 1981.]\n    4\t0x0004\tHesiod (HS)\t[Dyer, S., and F. Hsu, \"Hesiod\", Project Athena Technical Plan - Name Service, April 1987.]\n    5-253\t0x0005-0x00FD\tUnassigned\n    254\t0x00FE\tQCLASS NONE\t[RFC2136]\n    255\t0x00FF\tQCLASS * (ANY)\t[RFC1035]\n    256-65279\t0x0100-0xFEFF\tUnassigned\n    65280-65534\t0xFF00-0xFFFE\tReserved for Private Use\t[RFC6895]\n    65535\t0xFFFF\tReserved\t[RFC6895]\n\n# Multicasd DNS [RFC6762](https://datatracker.ietf.org/doc/html/rfc6762)\n\n The value 0x8001 in the rrclass field\n of a resource record in a Multicast DNS response message indicates a\n resource record with class 1, with the cache-flush bit set.  When\n receiving a resource record with the cache-flush bit set,\n implementations should take care to mask off that bit before storing\n the resource record in memory, or otherwise ensure that it is given\n the correct semantic interpretation.\n\n# Reference\n- [iana](https://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-2)\n- [Domain Name System (DNS) IANA Considerations](https://tools.ietf.org/html/rfc6895)\n- [YANG Types for DNS Classes and Resource Record Types](https://tools.ietf.org/html/rfc9108)","ref":"DNS.Class.html"},{"type":"function","title":"DNS.Class.internet/0","doc":"","ref":"DNS.Class.html#internet/0"},{"type":"function","title":"DNS.Class.new/1","doc":"# Create a new Class struct","ref":"DNS.Class.html#new/1"},{"type":"type","title":"DNS.Class.t/0","doc":"","ref":"DNS.Class.html#t:t/0"},{"type":"module","title":"DNS.Message","doc":"# DNS Message\n\nAll communications inside of the domain protocol are carried in a single\nformat called a message.  The top level format of message is divided\ninto 5 sections (some of which are empty in certain cases) shown below:\n\n    +---------------------+\n    |        Header       |\n    +---------------------+\n    |       Question      | the question for the name server\n    +---------------------+\n    |        Answer       | RRs answering the question\n    +---------------------+\n    |      Authority      | RRs pointing toward an authority\n    +---------------------+\n    |      Additional     | RRs holding additional information\n    +---------------------+\n\nThe header section is always present.  The header includes fields that\nspecify which of the remaining sections are present, and also specify\nwhether the message is a query or a response, a standard query or some\nother opcode, etc.\n\nThe names of the sections after the header are derived from their use in\nstandard queries.  The question section contains fields that describe a\nquestion to a name server.  These fields are a query type (QTYPE), a\nquery class (QCLASS), and a query domain name (QNAME).  The last three\nsections have the same format: a possibly empty list of concatenated\nresource records (RRs).  The answer section contains RRs that answer the\nquestion; the authority section contains RRs that point toward an\nauthoritative name server; the additional records section contains RRs\nwhich relate to the query, but are not strictly answers for the\nquestion.","ref":"DNS.Message.html"},{"type":"function","title":"DNS.Message.add_question/2","doc":"","ref":"DNS.Message.html#add_question/2"},{"type":"function","title":"DNS.Message.from_iodata/1","doc":"","ref":"DNS.Message.html#from_iodata/1"},{"type":"function","title":"DNS.Message.get_option/3","doc":"","ref":"DNS.Message.html#get_option/3"},{"type":"function","title":"DNS.Message.new/0","doc":"","ref":"DNS.Message.html#new/0"},{"type":"function","title":"DNS.Message.put_option/3","doc":"","ref":"DNS.Message.html#put_option/3"},{"type":"type","title":"DNS.Message.t/0","doc":"","ref":"DNS.Message.html#t:t/0"},{"type":"function","title":"DNS.Message.update_header_attr/3","doc":"","ref":"DNS.Message.html#update_header_attr/3"},{"type":"module","title":"DNS.Message.Domain","doc":"# DNS Domain","ref":"DNS.Message.Domain.html"},{"type":"function","title":"DNS.Message.Domain.from_iodata/2","doc":"Get name from bitstring, uncompress name in message","ref":"DNS.Message.Domain.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Domain.new/1","doc":"","ref":"DNS.Message.Domain.html#new/1"},{"type":"function","title":"DNS.Message.Domain.new/2","doc":"","ref":"DNS.Message.Domain.html#new/2"},{"type":"type","title":"DNS.Message.Domain.t/0","doc":"","ref":"DNS.Message.Domain.html#t:t/0"},{"type":"module","title":"DNS.Message.EDNS0","doc":"# EDNS0 moudle\nEDNS0 is defined in [RFC6891](https://datatracker.ietf.org/doc/html/rfc6891)\n\nWhen Message additional section includes a record with type 41,\nit is the OPT pseudo-RR, which includes EDNS0 information.\n\nAn OPT pseudo-RR (sometimes called a meta-RR) MAY be added to the\nadditional data section of a request.\n\nThe OPT RR has RR type 41.\n\nIf an OPT record is present in a received request, compliant\nresponders MUST include an OPT record in their respective responses.\n\nAn OPT record does not carry any DNS data.  It is used only to\ncontain control information pertaining to the question-and-answer\nsequence of a specific transaction.  OPT RRs MUST NOT be cached,\nforwarded, or stored in or loaded from master files.\n\nThe OPT RR MAY be placed anywhere within the additional data section.\nWhen an OPT RR is included within any DNS message, it MUST be the\nonly OPT RR in that message.  If a query message with more than one\nOPT RR is received, a FORMERR (RCODE=1) MUST be returned.  The\nplacement flexibility for the OPT RR does not override the need for\nthe TSIG or SIG(0) RRs to be the last in the additional section\nwhenever they are present.\n\nThe fixed part of an OPT RR is structured as follows:\n\n     +------------+--------------+------------------------------+\n     | Field Name | Field Type   | Description                  |\n     +------------+--------------+------------------------------+\n     | NAME       | domain name  | MUST be 0 (root domain)      |\n     | TYPE       | u_int16_t    | OPT (41)                     |\n     | CLASS      | u_int16_t    | requestor's UDP payload size |\n     | TTL        | u_int32_t    | extended RCODE and flags     |\n     | RDLEN      | u_int16_t    | length of all RDATA          |\n     | RDATA      | octet stream | {attribute,value} pairs      |\n     +------------+--------------+------------------------------+\n\nThe extended RCODE and flags, which OPT stores in the RR Time to Live\n(TTL) field, are structured as follows:\n\n                    +0 (MSB)                            +1 (LSB)\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n     0: |         EXTENDED-RCODE        |            VERSION            |\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n     2: | DO|                           Z                               |\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+","ref":"DNS.Message.EDNS0.html"},{"type":"module","title":"EXTENDED-RCODE - DNS.Message.EDNS0","doc":"Forms the upper 8 bits of extended 12-bit RCODE (together with the\n4 bits defined in [RFC1035].  Note that EXTENDED-RCODE value 0\nindicates that an unextended RCODE is in use (values 0 through\n15).","ref":"DNS.Message.EDNS0.html#module-extended-rcode"},{"type":"module","title":"VERSION - DNS.Message.EDNS0","doc":"Indicates the implementation level of the setter.  Full\nconformance with this specification is indicated by version '0'.\nRequestors are encouraged to set this to the lowest implemented\nlevel capable of expressing a transaction, to minimise the\nresponder and network load of discovering the greatest common\nimplementation level between requestor and responder.  A\nrequestor's version numbering strategy MAY ideally be a run-time\nconfiguration option.\n\nIf a responder does not implement the VERSION level of the\nrequest, then it MUST respond with RCODE=BADVERS.  All responses\nMUST be limited in format to the VERSION level of the request, but\nthe VERSION of each response SHOULD be the highest implementation\nlevel of the responder.  In this way, a requestor will learn the\nimplementation level of a responder as a side effect of every\nresponse, including error responses and including RCODE=BADVERS.","ref":"DNS.Message.EDNS0.html#module-version"},{"type":"module","title":"DO - DNS.Message.EDNS0","doc":"DNSSEC OK bit as defined by [RFC3225].","ref":"DNS.Message.EDNS0.html#module-do"},{"type":"module","title":"Z - DNS.Message.EDNS0","doc":"Set to zero by senders and ignored by receivers, unless modified\nin a subsequent specification.\n\nThe variable part of an OPT RR may contain zero or more options in\nthe RDATA.  Each option MUST be treated as a bit field.  Each option\nis encoded as:\n\n                    +0 (MSB)                            +1 (LSB)\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n     0: |                          OPTION-CODE                          |\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n     2: |                         OPTION-LENGTH                         |\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n     4: |                                                               |\n        /                          OPTION-DATA                          /\n        /                                                               /\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+","ref":"DNS.Message.EDNS0.html#module-z"},{"type":"module","title":"OPTION-CODE - DNS.Message.EDNS0","doc":"Assigned by the Expert Review process as defined by the DNSEXT\nworking group and the IESG.","ref":"DNS.Message.EDNS0.html#module-option-code"},{"type":"module","title":"OPTION-LENGTH - DNS.Message.EDNS0","doc":"Size (in octets) of OPTION-DATA.","ref":"DNS.Message.EDNS0.html#module-option-length"},{"type":"module","title":"OPTION-DATA - DNS.Message.EDNS0","doc":"Varies per OPTION-CODE.  MUST be treated as a bit field.\n\nThe order of appearance of option tuples is not defined.  If one\noption modifies the behaviour of another or multiple options are\nrelated to one another in some way, they have the same effect\nregardless of ordering in the RDATA wire encoding.\n\nAny OPTION-CODE values not understood by a responder or requestor\nMUST be ignored.  Specifications of such options might wish to\ninclude some kind of signaled acknowledgement.  For example, an\noption specification might say that if a responder sees and supports\noption XYZ, it MUST include option XYZ in its response.","ref":"DNS.Message.EDNS0.html#module-option-data"},{"type":"function","title":"DNS.Message.EDNS0.add_option/2","doc":"","ref":"DNS.Message.EDNS0.html#add_option/2"},{"type":"function","title":"DNS.Message.EDNS0.from_iodata/1","doc":"","ref":"DNS.Message.EDNS0.html#from_iodata/1"},{"type":"function","title":"DNS.Message.EDNS0.new/0","doc":"","ref":"DNS.Message.EDNS0.html#new/0"},{"type":"function","title":"DNS.Message.EDNS0.new/1","doc":"","ref":"DNS.Message.EDNS0.html#new/1"},{"type":"type","title":"DNS.Message.EDNS0.t/0","doc":"","ref":"DNS.Message.EDNS0.html#t:t/0"},{"type":"module","title":"DNS.Message.EDNS0.Option","doc":"DNS EDNS0","ref":"DNS.Message.EDNS0.Option.html"},{"type":"function","title":"DNS.Message.EDNS0.Option.from_iodata/1","doc":"","ref":"DNS.Message.EDNS0.Option.html#from_iodata/1"},{"type":"function","title":"DNS.Message.EDNS0.Option.new/2","doc":"","ref":"DNS.Message.EDNS0.Option.html#new/2"},{"type":"type","title":"DNS.Message.EDNS0.Option.t/0","doc":"","ref":"DNS.Message.EDNS0.Option.html#t:t/0"},{"type":"module","title":"DNS.Message.EDNS0.Option.Chain","doc":"EDNS0.Option.Chain [RFC7901](https://datatracker.ietf.org/doc/html/rfc7901)\n\nThe CHAIN option is used to request DNSSEC chain responses from\nauthoritative servers.\n\nOption Format:\n\n                      1 1 1 1 1 1 1 1 1 1 2 2 2 2 2 2 2 2 2 2 3 3\n  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |        OPTION-CODE = 13       |       OPTION-LENGTH = 2       |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |                      START-HASH                               |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n\n- START-HASH: 2 octets, DNSSEC algorithm identifier for the start of the chain","ref":"DNS.Message.EDNS0.Option.Chain.html"},{"type":"function","title":"DNS.Message.EDNS0.Option.Chain.from_iodata/1","doc":"","ref":"DNS.Message.EDNS0.Option.Chain.html#from_iodata/1"},{"type":"function","title":"DNS.Message.EDNS0.Option.Chain.new/1","doc":"","ref":"DNS.Message.EDNS0.Option.Chain.html#new/1"},{"type":"type","title":"DNS.Message.EDNS0.Option.Chain.t/0","doc":"","ref":"DNS.Message.EDNS0.Option.Chain.html#t:t/0"},{"type":"module","title":"DNS.Message.EDNS0.Option.Cookie","doc":"EDNS0.Option.Cookie\n\nThe DNS COOKIE option is an OPT RR [RFC6891] option that can be\nincluded in the RDATA portion of an OPT RR in DNS requests and\nresponses.  The option length varies, depending on the circumstances\nin which it is being used.  There are two cases, as described below.\nBoth use the same OPTION-CODE; they are distinguished by their\nlength.\n\nIn a request sent by a client to a server when the client does not\nknow the server's cookie, its length is 8, consisting of an 8-byte\nClient Cookie, as shown in Figure 1.\n\n                          1 1 1 1 1 1 1 1 1 1 2 2 2 2 2 2 2 2 2 2 3 3\n      0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n      +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n      |        OPTION-CODE = 10      |       OPTION-LENGTH = 8        |\n      +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n      |                                                               |\n      +-+-    Client Cookie (fixed size, 8 bytes)              -+-+-+-+\n      |                                                               |\n      +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n\n            Figure 1: COOKIE Option, Unknown Server Cookie\n\n In a request sent by a client when a Server Cookie is known, and in\n all responses to such a request, the length is variable -- from 16 to\n 40 bytes, consisting of an 8-byte Client Cookie followed by the\n variable-length (8 bytes to 32 bytes) Server Cookie, as shown in\n Figure 2.  The variability of the option length stems from the\n variable-length Server Cookie.  The Server Cookie is an integer\n number of bytes, with a minimum size of 8 bytes for security and a\n maximum size of 32 bytes for convenience of implementation.\n\n                          1 1 1 1 1 1 1 1 1 1 2 2 2 2 2 2 2 2 2 2 3 3\n      0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n      +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n      |        OPTION-CODE = 10      |   OPTION-LENGTH >= 16, <= 40   |\n      +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n      |                                                               |\n      +-+-    Client Cookie (fixed size, 8 bytes)              -+-+-+-+\n      |                                                               |\n      +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n      |                                                               |\n      /       Server Cookie  (variable size, 8 to 32 bytes)           /\n      /                                                               /\n      +-+-+-+-...\n\n             Figure 2: COOKIE Option, Known Server Cookie","ref":"DNS.Message.EDNS0.Option.Cookie.html"},{"type":"function","title":"DNS.Message.EDNS0.Option.Cookie.from_iodata/1","doc":"","ref":"DNS.Message.EDNS0.Option.Cookie.html#from_iodata/1"},{"type":"function","title":"DNS.Message.EDNS0.Option.Cookie.new/1","doc":"","ref":"DNS.Message.EDNS0.Option.Cookie.html#new/1"},{"type":"type","title":"DNS.Message.EDNS0.Option.Cookie.t/0","doc":"","ref":"DNS.Message.EDNS0.Option.Cookie.html#t:t/0"},{"type":"module","title":"DNS.Message.EDNS0.Option.DAU","doc":"EDNS0.Option.DAU [RFC6975](https://datatracker.ietf.org/doc/html/rfc6975)\n\nDNSSEC Algorithm Understood (DAU) option is used to indicate which\nDNSSEC algorithms a resolver understands.\n\nOption Format:\n\n                      1 1 1 1 1 1 1 1 1 1 2 2 2 2 2 2 2 2 2 2 3 3\n  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |        OPTION-CODE = 5        |       OPTION-LENGTH           |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |                                                               |\n  /                      ALGORITHM LIST                           /\n  /                                                               /\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n\n- ALGORITHM LIST: Variable length, list of DNSSEC algorithm codes","ref":"DNS.Message.EDNS0.Option.DAU.html"},{"type":"function","title":"DNS.Message.EDNS0.Option.DAU.from_iodata/1","doc":"","ref":"DNS.Message.EDNS0.Option.DAU.html#from_iodata/1"},{"type":"function","title":"DNS.Message.EDNS0.Option.DAU.new/1","doc":"","ref":"DNS.Message.EDNS0.Option.DAU.html#new/1"},{"type":"type","title":"DNS.Message.EDNS0.Option.DAU.t/0","doc":"","ref":"DNS.Message.EDNS0.Option.DAU.html#t:t/0"},{"type":"module","title":"DNS.Message.EDNS0.Option.DHU","doc":"EDNS0.Option.DHU [RFC6975](https://datatracker.ietf.org/doc/html/rfc6975)\n\nDS Hash Understood (DHU) option is used to indicate which DS hash\nalgorithms a resolver understands.\n\nOption Format:\n\n                      1 1 1 1 1 1 1 1 1 1 2 2 2 2 2 2 2 2 2 2 3 3\n  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |        OPTION-CODE = 6        |       OPTION-LENGTH           |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |                                                               |\n  /                      ALGORITHM LIST                           /\n  /                                                               /\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n\n- ALGORITHM LIST: Variable length, list of DS hash algorithm codes","ref":"DNS.Message.EDNS0.Option.DHU.html"},{"type":"function","title":"DNS.Message.EDNS0.Option.DHU.from_iodata/1","doc":"","ref":"DNS.Message.EDNS0.Option.DHU.html#from_iodata/1"},{"type":"function","title":"DNS.Message.EDNS0.Option.DHU.new/1","doc":"","ref":"DNS.Message.EDNS0.Option.DHU.html#new/1"},{"type":"type","title":"DNS.Message.EDNS0.Option.DHU.t/0","doc":"","ref":"DNS.Message.EDNS0.Option.DHU.html#t:t/0"},{"type":"module","title":"DNS.Message.EDNS0.Option.ECS","doc":"EDNS0.Option.ECS [RFC7871](https://datatracker.ietf.org/doc/html/rfc7871)\n\nOption Format\n\n This protocol uses an EDNS0 [RFC6891] option to include client\n address information in DNS messages.  The option is structured as\n follows:\n\n                  +0 (MSB)                            +1 (LSB)\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n    0: |                          OPTION-CODE                          |\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n    2: |                         OPTION-LENGTH                         |\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n    4: |                            FAMILY                             |\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n    6: |     SOURCE PREFIX-LENGTH      |     SCOPE PREFIX-LENGTH       |\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n    8: |                           ADDRESS...                          /\n        +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n\n o  (Defined in [RFC6891]) OPTION-CODE, 2 octets, for ECS is 8 (0x00\n    0x08).\n\n o  (Defined in [RFC6891]) OPTION-LENGTH, 2 octets, contains the\n    length of the payload (everything after OPTION-LENGTH) in octets.\n\n o  FAMILY, 2 octets, indicates the family of the address contained in\n    the option, using address family codes as assigned by IANA in\n    Address Family Numbers [Address_Family_Numbers].\n\n The format of the address part depends on the value of FAMILY.  This\n document only defines the format for FAMILY 1 (IPv4) and FAMILY 2\n (IPv6), which are as follows:\n\n o  SOURCE PREFIX-LENGTH, an unsigned octet representing the leftmost\n    number of significant bits of ADDRESS to be used for the lookup.\n    In responses, it mirrors the same value as in the queries.\n\n o  SCOPE PREFIX-LENGTH, an unsigned octet representing the leftmost\n    number of significant bits of ADDRESS that the response covers.\n    In queries, it MUST be set to 0.\n\n o  ADDRESS, variable number of octets, contains either an IPv4 or\n    IPv6 address, depending on FAMILY, which MUST be truncated to the\n    number of bits indicated by the SOURCE PREFIX-LENGTH field,\n    padding with 0 bits to pad to the end of the last octet needed.\n\n o  A server receiving an ECS option that uses either too few or too\n    many ADDRESS octets, or that has non-zero ADDRESS bits set beyond\n    SOURCE PREFIX-LENGTH, SHOULD return FORMERR to reject the packet,\n    as a signal to the software developer making the request to fix\n    their implementation.\n\n All fields are in network byte order (\"big-endian\", per [RFC1700],\n Data Notation).","ref":"DNS.Message.EDNS0.Option.ECS.html"},{"type":"function","title":"DNS.Message.EDNS0.Option.ECS.from_iodata/1","doc":"","ref":"DNS.Message.EDNS0.Option.ECS.html#from_iodata/1"},{"type":"function","title":"DNS.Message.EDNS0.Option.ECS.new/1","doc":"","ref":"DNS.Message.EDNS0.Option.ECS.html#new/1"},{"type":"type","title":"DNS.Message.EDNS0.Option.ECS.t/0","doc":"","ref":"DNS.Message.EDNS0.Option.ECS.html#t:t/0"},{"type":"function","title":"DNS.Message.EDNS0.Option.ECS.to_raw/1","doc":"","ref":"DNS.Message.EDNS0.Option.ECS.html#to_raw/1"},{"type":"module","title":"DNS.Message.EDNS0.Option.Expire","doc":"EDNS0.Option.Expire [RFC7314](https://datatracker.ietf.org/doc/html/rfc7314)\n\nThe EDNS EXPIRE option is used to communicate the remaining time\nuntil a cached resource record expires.\n\nOption Format:\n\n                      1 1 1 1 1 1 1 1 1 1 2 2 2 2 2 2 2 2 2 2 3 3\n  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |        OPTION-CODE = 9        |       OPTION-LENGTH = 4       |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |                       EXPIRE-TIME                             |\n  |                                                               |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n\n- EXPIRE-TIME: 4 octets, remaining time until expiration in seconds","ref":"DNS.Message.EDNS0.Option.Expire.html"},{"type":"function","title":"DNS.Message.EDNS0.Option.Expire.from_iodata/1","doc":"","ref":"DNS.Message.EDNS0.Option.Expire.html#from_iodata/1"},{"type":"function","title":"DNS.Message.EDNS0.Option.Expire.new/1","doc":"","ref":"DNS.Message.EDNS0.Option.Expire.html#new/1"},{"type":"type","title":"DNS.Message.EDNS0.Option.Expire.t/0","doc":"","ref":"DNS.Message.EDNS0.Option.Expire.html#t:t/0"},{"type":"module","title":"DNS.Message.EDNS0.Option.ExtendedDNSError","doc":"EDNS0.Option.ExtendedDNSError [RFC8914](https://datatracker.ietf.org/doc/html/rfc8914)\n\nThe Extended DNS Error (EDE) option provides additional error\ninformation beyond the basic DNS RCODE.\n\nOption Format:\n\n                      1 1 1 1 1 1 1 1 1 1 2 2 2 2 2 2 2 2 2 2 3 3\n  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |        OPTION-CODE = 15       |       OPTION-LENGTH           |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |           INFO-CODE           |           EXTRA-TEXT          |\n  |                                                               |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n\n- INFO-CODE: 2 octets, extended error code\n- EXTRA-TEXT: Variable length, human-readable error text (UTF-8)","ref":"DNS.Message.EDNS0.Option.ExtendedDNSError.html"},{"type":"function","title":"DNS.Message.EDNS0.Option.ExtendedDNSError.from_iodata/1","doc":"","ref":"DNS.Message.EDNS0.Option.ExtendedDNSError.html#from_iodata/1"},{"type":"function","title":"DNS.Message.EDNS0.Option.ExtendedDNSError.new/1","doc":"","ref":"DNS.Message.EDNS0.Option.ExtendedDNSError.html#new/1"},{"type":"type","title":"DNS.Message.EDNS0.Option.ExtendedDNSError.t/0","doc":"","ref":"DNS.Message.EDNS0.Option.ExtendedDNSError.html#t:t/0"},{"type":"module","title":"DNS.Message.EDNS0.Option.KeyTag","doc":"EDNS0.Option.KeyTag [RFC8145](https://datatracker.ietf.org/doc/html/rfc8145)\n\nThe edns-key-tag option is used to communicate DNSSEC key tags that\na resolver trusts for a particular zone.\n\nOption Format:\n\n                      1 1 1 1 1 1 1 1 1 1 2 2 2 2 2 2 2 2 2 2 3 3\n  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |        OPTION-CODE = 14       |       OPTION-LENGTH           |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |                                                               |\n  /                      KEY-TAG LIST                             /\n  /                                                               /\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n\n- KEY-TAG LIST: Variable length, list of DNSSEC key tags (2 octets each)","ref":"DNS.Message.EDNS0.Option.KeyTag.html"},{"type":"function","title":"DNS.Message.EDNS0.Option.KeyTag.from_iodata/1","doc":"","ref":"DNS.Message.EDNS0.Option.KeyTag.html#from_iodata/1"},{"type":"function","title":"DNS.Message.EDNS0.Option.KeyTag.new/1","doc":"","ref":"DNS.Message.EDNS0.Option.KeyTag.html#new/1"},{"type":"type","title":"DNS.Message.EDNS0.Option.KeyTag.t/0","doc":"","ref":"DNS.Message.EDNS0.Option.KeyTag.html#t:t/0"},{"type":"module","title":"DNS.Message.EDNS0.Option.LLQ","doc":"EDNS0.Option.LLQ [RFC8764](https://datatracker.ietf.org/doc/html/rfc8764)\n\nThe DNS Long-Lived Queries (LLQ) option is used to enable DNS clients\nto receive asynchronous notifications when resource records change.\n\nOption Format:\n\n                      1 1 1 1 1 1 1 1 1 1 2 2 2 2 2 2 2 2 2 2 3 3\n  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |        OPTION-CODE = 1        |       OPTION-LENGTH = 18      |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |          LLQ-Version          |              LLQ-Opcode        |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |                            LLQ-ID                             |\n  |                                                               |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |                          LLQ-LEASE-LIFE                       |\n  |                                                               |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n\n- LLQ-Version: 2 octets, must be set to 1\n- LLQ-Opcode: 2 octets, identifies the LLQ operation\n- LLQ-ID: 8 octets, unique identifier for the LLQ\n- LLQ-LEASE-LIFE: 4 octets, lease duration in seconds","ref":"DNS.Message.EDNS0.Option.LLQ.html"},{"type":"function","title":"DNS.Message.EDNS0.Option.LLQ.from_iodata/1","doc":"","ref":"DNS.Message.EDNS0.Option.LLQ.html#from_iodata/1"},{"type":"function","title":"DNS.Message.EDNS0.Option.LLQ.new/1","doc":"","ref":"DNS.Message.EDNS0.Option.LLQ.html#new/1"},{"type":"type","title":"DNS.Message.EDNS0.Option.LLQ.t/0","doc":"","ref":"DNS.Message.EDNS0.Option.LLQ.html#t:t/0"},{"type":"module","title":"DNS.Message.EDNS0.Option.N3U","doc":"EDNS0.Option.N3U [RFC6975](https://datatracker.ietf.org/doc/html/rfc6975)\n\nNSEC3 Hash Understood (N3U) option is used to indicate which NSEC3 hash\nalgorithms a resolver understands.\n\nOption Format:\n\n                      1 1 1 1 1 1 1 1 1 1 2 2 2 2 2 2 2 2 2 2 3 3\n  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |        OPTION-CODE = 7        |       OPTION-LENGTH           |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |                                                               |\n  /                      ALGORITHM LIST                           /\n  /                                                               /\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n\n- ALGORITHM LIST: Variable length, list of NSEC3 hash algorithm codes","ref":"DNS.Message.EDNS0.Option.N3U.html"},{"type":"function","title":"DNS.Message.EDNS0.Option.N3U.from_iodata/1","doc":"","ref":"DNS.Message.EDNS0.Option.N3U.html#from_iodata/1"},{"type":"function","title":"DNS.Message.EDNS0.Option.N3U.new/1","doc":"","ref":"DNS.Message.EDNS0.Option.N3U.html#new/1"},{"type":"type","title":"DNS.Message.EDNS0.Option.N3U.t/0","doc":"","ref":"DNS.Message.EDNS0.Option.N3U.html#t:t/0"},{"type":"module","title":"DNS.Message.EDNS0.Option.NSID","doc":"EDNS0.Option.NSID [RFC5001](https://datatracker.ietf.org/doc/html/rfc5001)\n\nThe Name Server ID (NSID) option is used to identify a specific name\nserver that responded to a DNS query.\n\nOption Format:\n\n                      1 1 1 1 1 1 1 1 1 1 2 2 2 2 2 2 2 2 2 2 3 3\n  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |        OPTION-CODE = 3        |       OPTION-LENGTH           |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |                                                               |\n  /                          NSID DATA                            /\n  /                                                               /\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n\n- NSID DATA: Variable length, up to 65535 octets","ref":"DNS.Message.EDNS0.Option.NSID.html"},{"type":"function","title":"DNS.Message.EDNS0.Option.NSID.from_iodata/1","doc":"","ref":"DNS.Message.EDNS0.Option.NSID.html#from_iodata/1"},{"type":"function","title":"DNS.Message.EDNS0.Option.NSID.new/1","doc":"","ref":"DNS.Message.EDNS0.Option.NSID.html#new/1"},{"type":"type","title":"DNS.Message.EDNS0.Option.NSID.t/0","doc":"","ref":"DNS.Message.EDNS0.Option.NSID.html#t:t/0"},{"type":"module","title":"DNS.Message.EDNS0.Option.Padding","doc":"EDNS0.Option.Padding [RFC7830](https://datatracker.ietf.org/doc/html/rfc7830)\n\nThe Padding option is used to pad DNS messages to a specific size\nto prevent traffic analysis attacks.\n\nOption Format:\n\n                      1 1 1 1 1 1 1 1 1 1 2 2 2 2 2 2 2 2 2 2 3 3\n  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |        OPTION-CODE = 12       |       OPTION-LENGTH           |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |                                                               |\n  /                        PADDING DATA                           /\n  /                                                               /\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n\n- PADDING DATA: Variable length, typically zeros or random data","ref":"DNS.Message.EDNS0.Option.Padding.html"},{"type":"function","title":"DNS.Message.EDNS0.Option.Padding.from_iodata/1","doc":"","ref":"DNS.Message.EDNS0.Option.Padding.html#from_iodata/1"},{"type":"function","title":"DNS.Message.EDNS0.Option.Padding.new/1","doc":"","ref":"DNS.Message.EDNS0.Option.Padding.html#new/1"},{"type":"type","title":"DNS.Message.EDNS0.Option.Padding.t/0","doc":"","ref":"DNS.Message.EDNS0.Option.Padding.html#t:t/0"},{"type":"module","title":"DNS.Message.EDNS0.Option.TcpKeepalive","doc":"EDNS0.Option.TcpKeepalive [RFC7828](https://datatracker.ietf.org/doc/html/rfc7828)\n\nThe edns-tcp-keepalive option is used to negotiate TCP keepalive\nparameters between DNS clients and servers.\n\nOption Format:\n\n                      1 1 1 1 1 1 1 1 1 1 2 2 2 2 2 2 2 2 2 2 3 3\n  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |        OPTION-CODE = 11       |       OPTION-LENGTH           |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |                      TIMEOUT-COUNT                            |\n  |                                                               |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n\n- TIMEOUT-COUNT: 2 octets, timeout value in 100ms units (or 0 if not specified)","ref":"DNS.Message.EDNS0.Option.TcpKeepalive.html"},{"type":"function","title":"DNS.Message.EDNS0.Option.TcpKeepalive.from_iodata/1","doc":"","ref":"DNS.Message.EDNS0.Option.TcpKeepalive.html#from_iodata/1"},{"type":"function","title":"DNS.Message.EDNS0.Option.TcpKeepalive.new/1","doc":"","ref":"DNS.Message.EDNS0.Option.TcpKeepalive.html#new/1"},{"type":"type","title":"DNS.Message.EDNS0.Option.TcpKeepalive.t/0","doc":"","ref":"DNS.Message.EDNS0.Option.TcpKeepalive.html#t:t/0"},{"type":"module","title":"DNS.Message.EDNS0.Option.UpdateLease","doc":"EDNS0.Option.UpdateLease [RFC-ietf-dnssd-update-lease-08]\n\nThe Update Lease option is used in DNS-SD (DNS Service Discovery)\nto indicate the lease duration for resource record updates.\n\nOption Format:\n\n                      1 1 1 1 1 1 1 1 1 1 2 2 2 2 2 2 2 2 2 2 3 3\n  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |        OPTION-CODE = 2        |       OPTION-LENGTH = 4       |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n  |                       LEASE-LIFETIME                         |\n  |                                                               |\n  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n\n- LEASE-LIFETIME: 4 octets, lease duration in seconds","ref":"DNS.Message.EDNS0.Option.UpdateLease.html"},{"type":"function","title":"DNS.Message.EDNS0.Option.UpdateLease.from_iodata/1","doc":"","ref":"DNS.Message.EDNS0.Option.UpdateLease.html#from_iodata/1"},{"type":"function","title":"DNS.Message.EDNS0.Option.UpdateLease.new/1","doc":"","ref":"DNS.Message.EDNS0.Option.UpdateLease.html#new/1"},{"type":"type","title":"DNS.Message.EDNS0.Option.UpdateLease.t/0","doc":"","ref":"DNS.Message.EDNS0.Option.UpdateLease.html#t:t/0"},{"type":"module","title":"DNS.Message.EDNS0.OptionCode","doc":"DNS EDNS0 Option Codes (OPT)\n\n      0\tReserved\t\t[RFC6891](https://datatracker.ietf.org/doc/html/rfc6891)\n      1\tLLQ\tOptional\t[RFC8764](https://datatracker.ietf.org/doc/html/rfc8764)\n      2\tUpdate Lease\tStandard\t[RFC-ietf-dnssd-update-lease-08]\n      3\tNSID\tStandard\t[RFC5001](https://datatracker.ietf.org/doc/html/rfc5001)\n      4\tReserved\t\t[draft-cheshire-edns0-owner-option]\n      5\tDAU\tStandard\t[RFC6975](https://datatracker.ietf.org/doc/html/rfc6975)\n      6\tDHU\tStandard\t[RFC6975](https://datatracker.ietf.org/doc/html/rfc6975)\n      7\tN3U\tStandard\t[RFC6975](https://datatracker.ietf.org/doc/html/rfc6975)\n      8\tedns-client-subnet\tOptional\t[RFC7871](https://datatracker.ietf.org/doc/html/rfc7871)\n      9\tEDNS EXPIRE\tOptional\t[RFC7314](https://datatracker.ietf.org/doc/html/rfc7314)\n      10\tCOOKIE\tStandard\t[RFC7873](https://datatracker.ietf.org/doc/html/rfc7873)\n      11\tedns-tcp-keepalive\tStandard\t[RFC7828](https://datatracker.ietf.org/doc/html/rfc7828)\n      12\tPadding\tStandard\t[RFC7830](https://datatracker.ietf.org/doc/html/rfc7830)\n      13\tCHAIN\tStandard\t[RFC7901](https://datatracker.ietf.org/doc/html/rfc7901)\n      14\tedns-key-tag\tOptional\t[RFC8145](https://datatracker.ietf.org/doc/html/rfc8145)\n      15\tExtended DNS Error\tStandard\t[RFC8914](https://datatracker.ietf.org/doc/html/rfc8914)\n      16\tEDNS-Client-Tag\tOptional\t[draft-bellis-dnsop-edns-tags]\n      17\tEDNS-Server-Tag\tOptional\t[draft-bellis-dnsop-edns-tags]\n      18\tReport-Channel\tStandard\t[RFC9567](https://datatracker.ietf.org/doc/html/rfc9567)\n      19-20291\tUnassigned\n      20292\tUmbrella Ident\tOptional\t[https://developer.cisco.com/docs/cloud-security/#!integrating-network-devices/rdata-description][Cisco_CIE_DNS_team]\n      20293-26945\tUnassigned\n      26946\tDeviceID\tOptional\t[https://developer.cisco.com/docs/cloud-security/#!network-devices-getting-started/response-codes][Cisco_CIE_DNS_team]\n      26947-65000\tUnassigned\n      65001-65534\tReserved for Local/Experimental Use\t\t[RFC6891](https://datatracker.ietf.org/doc/html/rfc6891)\n      65535\tReserved for future expansion\t\t[RFC6891](https://datatracker.ietf.org/doc/html/rfc6891)","ref":"DNS.Message.EDNS0.OptionCode.html"},{"type":"function","title":"DNS.Message.EDNS0.OptionCode.new/1","doc":"# Create a new OptionCode struct","ref":"DNS.Message.EDNS0.OptionCode.html#new/1"},{"type":"type","title":"DNS.Message.EDNS0.OptionCode.t/0","doc":"","ref":"DNS.Message.EDNS0.OptionCode.html#t:t/0"},{"type":"module","title":"DNS.Message.Header","doc":"# DNS Header\n\nThe header contains the following fields:\n\n                                    1  1  1  1  1  1\n      0  1  2  3  4  5  6  7  8  9  0  1  2  3  4  5\n    +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n    |                      ID                       |\n    +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n    |QR|   Opcode  |AA|TC|RD|RA|   Z    |   RCODE   |\n    +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n    |                    QDCOUNT                    |\n    +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n    |                    ANCOUNT                    |\n    +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n    |                    NSCOUNT                    |\n    +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n    |                    ARCOUNT                    |\n    +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n\nwhere:\n\n- `ID`\n\nA 16 bit identifier assigned by the program that\ngenerates any kind of query.  This identifier is copied\nthe corresponding reply and can be used by the requester\nto match up replies to outstanding queries.\n\n- `QR`\n\nA one bit field that specifies whether this message is a\nquery (0), or a response (1).\n\n- `OPCODE`\n\nA four bit field that specifies kind of query in this\nmessage.  This value is set by the originator of a query\nand copied into the response.\n\n- `AA`\n\nAuthoritative Answer - this bit is valid in responses,\nand specifies that the responding name server is an\nauthority for the domain name in question section.\n\nNote that the contents of the answer section may have\nmultiple owner names because of aliases.  The AA bit\ncorresponds to the name which matches the query name, or\nthe first owner name in the answer section.\n\n- `TC`\n\nTrunCation - specifies that this message was truncated\ndue to length greater than that permitted on the\ntransmission channel.\n\n- `RD`\n\nRecursion Desired - this bit may be set in a query and\nis copied into the response.  If RD is set, it directs\nthe name server to pursue the query recursively.\nRecursive query support is optional.\n\n- `RA`\n\nRecursion Available - this be is set or cleared in a\nresponse, and denotes whether recursive query support is\navailable in the name server.\n\n- `Z`\n\nReserved for future use.  Must be zero in all queries\nand responses.\n\n- `AD`\n\nThe AD bit exists in order to provide a means for a security-aware\nresolver to signal to a security-aware name server that the resolver\nconsiders authentic data to be more important than unauthenticated\ndata.  The AD bit is only intended to provide a signal from the\nresolver to the name server; it is not intended to provide a signal\nfrom the name server to the resolver.\n\n[rfc4035]\n\n- `CD`\n\nThe CD bit exists in order to allow a security-aware resolver to\ndisable signature validation in a security-aware name server's\nprocessing of a particular query.\n\n[rfc4035]\n\n- `RCODE`\n\nResponse code - this 4 bit field is set as part of\nresponses.\n\n- `QDCOUNT`\n\nan unsigned 16 bit integer specifying the number of\nentries in the question section.\n\n- `ANCOUNT`\n\nan unsigned 16 bit integer specifying the number of\nresource records in the answer section.\n\n- `NSCOUNT`\n\nan unsigned 16 bit integer specifying the number of name\nserver resource records in the authority records\nsection.\n\n- `ARCOUNT`\n\nan unsigned 16 bit integer specifying the number of\nresource records in the additional records section.\n\n\n# Reference\n- [iana](https://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-5)\n- [DOMAIN NAMES - IMPLEMENTATION AND SPECIFICATION](https://tools.ietf.org/html/rfc1035)\n- [Domain Name System (DNS) IANA Considerations](https://tools.ietf.org/html/rfc6895)","ref":"DNS.Message.Header.html"},{"type":"function","title":"DNS.Message.Header.ancount/1","doc":"","ref":"DNS.Message.Header.html#ancount/1"},{"type":"function","title":"DNS.Message.Header.arcount/1","doc":"","ref":"DNS.Message.Header.html#arcount/1"},{"type":"function","title":"DNS.Message.Header.generate_id/0","doc":"","ref":"DNS.Message.Header.html#generate_id/0"},{"type":"function","title":"DNS.Message.Header.new/0","doc":"","ref":"DNS.Message.Header.html#new/0"},{"type":"function","title":"DNS.Message.Header.nscount/1","doc":"","ref":"DNS.Message.Header.html#nscount/1"},{"type":"function","title":"DNS.Message.Header.qdcount/1","doc":"","ref":"DNS.Message.Header.html#qdcount/1"},{"type":"type","title":"DNS.Message.Header.t/0","doc":"","ref":"DNS.Message.Header.html#t:t/0"},{"type":"module","title":"DNS.Message.OpCode","doc":"# DNS OpCode\n\n    OpCode \tName \tReference\n    0\tQuery\t[RFC1035]\n    1\tIQuery (Inverse Query, OBSOLETE)\t[RFC3425]\n    2\tStatus\t[RFC1035]\n    3\tUnassigned\n    4\tNotify\t[RFC1996]\n    5\tUpdate\t[RFC2136]\n    6\tDNS Stateful Operations (DSO)\t[RFC8490]\n    7-15\tUnassigned\n\n# Reference\n- [iana](https://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-5)\n- [DOMAIN NAMES - IMPLEMENTATION AND SPECIFICATION](https://tools.ietf.org/html/rfc1035)\n- [Domain Name System (DNS) IANA Considerations](https://tools.ietf.org/html/rfc6895)","ref":"DNS.Message.OpCode.html"},{"type":"function","title":"DNS.Message.OpCode.dso/0","doc":"# dso is a non-standard extension to DNS that is used by the\n[DNS Stateful Operations (DSO)](https://tools.ietf.org/html/draft-sekar-dns-ultradns-00)","ref":"DNS.Message.OpCode.html#dso/0"},{"type":"function","title":"DNS.Message.OpCode.iquery/0","doc":"# iquery is a non-standard extension to DNS that is used by the\n[DNS Zone Transfer Protocol](https://tools.ietf.org/html/rfc1996)","ref":"DNS.Message.OpCode.html#iquery/0"},{"type":"function","title":"DNS.Message.OpCode.new/1","doc":"","ref":"DNS.Message.OpCode.html#new/1"},{"type":"function","title":"DNS.Message.OpCode.notify/0","doc":"# notify is a non-standard extension to DNS that is used by the\n[DNS Zone Transfer Protocol](https://tools.ietf.org/html/rfc1996)","ref":"DNS.Message.OpCode.html#notify/0"},{"type":"function","title":"DNS.Message.OpCode.query/0","doc":"# query is a standard query\n[RFC1035](https://tools.ietf.org/html/rfc1035)","ref":"DNS.Message.OpCode.html#query/0"},{"type":"function","title":"DNS.Message.OpCode.status/0","doc":"# status is a non-standard extension to DNS that is used by the\n[DNS Zone Transfer Protocol](https://tools.ietf.org/html/rfc1996)","ref":"DNS.Message.OpCode.html#status/0"},{"type":"type","title":"DNS.Message.OpCode.t/0","doc":"","ref":"DNS.Message.OpCode.html#t:t/0"},{"type":"function","title":"DNS.Message.OpCode.update/0","doc":"# update is a non-standard extension to DNS that is used by the\n[Dynamic DNS Update](https://tools.ietf.org/html/rfc2136)","ref":"DNS.Message.OpCode.html#update/0"},{"type":"module","title":"DNS.Message.Question","doc":"# DNS Question","ref":"DNS.Message.Question.html"},{"type":"function","title":"DNS.Message.Question.from_iodata/2","doc":"","ref":"DNS.Message.Question.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Question.list_from_message/1","doc":"","ref":"DNS.Message.Question.html#list_from_message/1"},{"type":"function","title":"DNS.Message.Question.list_from_message/2","doc":"","ref":"DNS.Message.Question.html#list_from_message/2"},{"type":"function","title":"DNS.Message.Question.list_to_iodata/1","doc":"","ref":"DNS.Message.Question.html#list_to_iodata/1"},{"type":"function","title":"DNS.Message.Question.new/3","doc":"","ref":"DNS.Message.Question.html#new/3"},{"type":"type","title":"DNS.Message.Question.t/0","doc":"","ref":"DNS.Message.Question.html#t:t/0"},{"type":"module","title":"DNS.Message.RCode","doc":"# DNS RCode\nDNS return code\n\nIt would appear from the DNS header that only four bits of\nRCODE, or response/error code, are available.  However, RCODEs can\nappear not only at the top level of a DNS response but also inside\nTSIG RRs [RFC2845], TKEY RRs [RFC2930], and extended by OPT RRs\n[RFC6891].  The OPT RR provides an 8-bit extension to the 4 header\nbits, resulting in a 12-bit RCODE field, and the TSIG and TKEY RRs\nhave a 16-bit field designated in their RFCs as the \"Error\" field.\n\nError codes appearing in the DNS header and in these other RR types\nall refer to the same error code space with the exception of error\ncode 16, which has a different meaning in the OPT RR than in the TSIG\nRR, and error code 9, whose variations are described after the table\nbelow.  The duplicate assignment of 16 was accidental.  To the extent\nthat any prior RFCs imply any sort of different error number space\nfor the OPT, TSIG, or TKEY RRs, they are superseded by this unified\nDNS error number space.  (This paragraph is the reason this document\nupdates [RFC2845] and [RFC2930].)  With the existing exceptions of\nerror numbers 9 and 16, the same error number must not be assigned\nfor different errors even if they would only occur in different RR\ntypes.  See table below.\n\n    Range \tRegistration Procedures\n    0-3840\tIETF Review\n    3841-4095\tPrivate Use\n    4096-65534\tIETF Review\n    65535\tReserved (Standards Action)\n\n    RCODE \tName \tDescription \tReference\n    0\tNoError\tNo Error\t[RFC1035]\n    1\tFormErr\tFormat Error\t[RFC1035]\n    2\tServFail\tServer Failure\t[RFC1035]\n    3\tNXDomain\tNon-Existent Domain\t[RFC1035]\n    4\tNotImp\tNot Implemented\t[RFC1035]\n    5\tRefused\tQuery Refused\t[RFC1035]\n    6\tYXDomain\tName Exists when it should not\t[RFC2136][RFC6672]\n    7\tYXRRSet\tRR Set Exists when it should not\t[RFC2136]\n    8\tNXRRSet\tRR Set that should exist does not\t[RFC2136]\n    9\tNotAuth\tServer Not Authoritative for zone\t[RFC2136]\n    9\tNotAuth\tNot Authorized\t[RFC8945]\n    10\tNotZone\tName not contained in zone\t[RFC2136]\n    11\tDSOTYPENI\tDSO-TYPE Not Implemented\t[RFC8490]\n    12-15\tUnassigned\n    16\tBADVERS\tBad OPT Version\t[RFC6891]\n    16\tBADSIG\tTSIG Signature Failure\t[RFC8945]\n    17\tBADKEY\tKey not recognized\t[RFC8945]\n    18\tBADTIME\tSignature out of time window\t[RFC8945]\n    19\tBADMODE\tBad TKEY Mode\t[RFC2930]\n    20\tBADNAME\tDuplicate key name\t[RFC2930]\n    21\tBADALG\tAlgorithm not supported\t[RFC2930]\n    22\tBADTRUNC\tBad Truncation\t[RFC8945]\n    23\tBADCOOKIE\tBad/missing Server Cookie\t[RFC7873]\n    24-3840\tUnassigned\n    3841-4095\tReserved for Private Use\t\t[RFC6895]\n    4096-65534\tUnassigned\n    65535\tReserved, can be allocated by Standards Action\t\t[RFC6895]\n\n# Reference\n- [iana](https://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-6)\n- [DOMAIN NAMES - IMPLEMENTATION AND SPECIFICATION](https://tools.ietf.org/html/rfc1035)\n- [Domain Name System (DNS) IANA Considerations](https://tools.ietf.org/html/rfc6895)","ref":"DNS.Message.RCode.html"},{"type":"function","title":"DNS.Message.RCode.dso_type_ni/0","doc":"","ref":"DNS.Message.RCode.html#dso_type_ni/0"},{"type":"function","title":"DNS.Message.RCode.extend/2","doc":"","ref":"DNS.Message.RCode.html#extend/2"},{"type":"function","title":"DNS.Message.RCode.form_err/0","doc":"","ref":"DNS.Message.RCode.html#form_err/0"},{"type":"function","title":"DNS.Message.RCode.new/1","doc":"","ref":"DNS.Message.RCode.html#new/1"},{"type":"function","title":"DNS.Message.RCode.no_error/0","doc":"","ref":"DNS.Message.RCode.html#no_error/0"},{"type":"function","title":"DNS.Message.RCode.not_auth/0","doc":"","ref":"DNS.Message.RCode.html#not_auth/0"},{"type":"function","title":"DNS.Message.RCode.not_imp/0","doc":"","ref":"DNS.Message.RCode.html#not_imp/0"},{"type":"function","title":"DNS.Message.RCode.not_zone/0","doc":"","ref":"DNS.Message.RCode.html#not_zone/0"},{"type":"function","title":"DNS.Message.RCode.nx_domain/0","doc":"","ref":"DNS.Message.RCode.html#nx_domain/0"},{"type":"function","title":"DNS.Message.RCode.nx_rrset/0","doc":"","ref":"DNS.Message.RCode.html#nx_rrset/0"},{"type":"function","title":"DNS.Message.RCode.refused/0","doc":"","ref":"DNS.Message.RCode.html#refused/0"},{"type":"function","title":"DNS.Message.RCode.serv_fail/0","doc":"","ref":"DNS.Message.RCode.html#serv_fail/0"},{"type":"type","title":"DNS.Message.RCode.t/0","doc":"","ref":"DNS.Message.RCode.html#t:t/0"},{"type":"function","title":"DNS.Message.RCode.yx_domain/0","doc":"","ref":"DNS.Message.RCode.html#yx_domain/0"},{"type":"function","title":"DNS.Message.RCode.yx_rrset/0","doc":"","ref":"DNS.Message.RCode.html#yx_rrset/0"},{"type":"module","title":"DNS.Message.Record","doc":"Record is a struct that represents a DNS resource record.\n\n  All RRs have the same top level format shown below:\n\n  ```txt\n                                      1  1  1  1  1  1\n        0  1  2  3  4  5  6  7  8  9  0  1  2  3  4  5\n      +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n      |                                               |\n      /                                               /\n      /                      NAME                     /\n      |                                               |\n      +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n      |                      TYPE                     |\n      +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n      |                     CLASS                     |\n      +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n      |                      TTL                      |\n      |                                               |\n      +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n      |                   RDLENGTH                    |\n      +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--|\n      /                     RDATA                     /\n      /                                               /\n      +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+\n  ```\n\n  where:\n\n  NAME            an owner name, i.e., the name of the node to which this\n                  resource record pertains.\n\n  TYPE            two octets containing one of the RR TYPE codes.\n\n  CLASS           two octets containing one of the RR CLASS codes.\n\n  TTL             a 32 bit signed integer that specifies the time interval\n                  that the resource record may be cached before the source\n                  of the information should again be consulted.  Zero\n                  values are interpreted to mean that the RR can only be\n                  used for the transaction in progress, and should not be\n                  cached.  For example, SOA records are always distributed\n                  with a zero TTL to prohibit caching.  Zero values can\n                  also be used for extremely volatile data.\n\n  RDLENGTH        an unsigned 16 bit integer that specifies the length in\n                  octets of the RDATA field.\n\n  RDATA           a variable length string of octets that describes the\n                  resource.  The format of this information varies\n                  according to the TYPE and CLASS of the resource record.","ref":"DNS.Message.Record.html"},{"type":"function","title":"DNS.Message.Record.from_iodata/2","doc":"","ref":"DNS.Message.Record.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.list_from_message/3","doc":"","ref":"DNS.Message.Record.html#list_from_message/3"},{"type":"function","title":"DNS.Message.Record.new/5","doc":"","ref":"DNS.Message.Record.html#new/5"},{"type":"type","title":"DNS.Message.Record.t/0","doc":"","ref":"DNS.Message.Record.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data","doc":"","ref":"DNS.Message.Record.Data.html"},{"type":"function","title":"DNS.Message.Record.Data.from_iodata/3","doc":"","ref":"DNS.Message.Record.Data.html#from_iodata/3"},{"type":"function","title":"DNS.Message.Record.Data.new/2","doc":"","ref":"DNS.Message.Record.Data.html#new/2"},{"type":"type","title":"DNS.Message.Record.Data.t/0","doc":"","ref":"DNS.Message.Record.Data.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.A","doc":"","ref":"DNS.Message.Record.Data.A.html"},{"type":"function","title":"DNS.Message.Record.Data.A.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.A.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.A.new/1","doc":"","ref":"DNS.Message.Record.Data.A.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.A.t/0","doc":"","ref":"DNS.Message.Record.Data.A.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.AAAA","doc":"","ref":"DNS.Message.Record.Data.AAAA.html"},{"type":"function","title":"DNS.Message.Record.Data.AAAA.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.AAAA.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.AAAA.new/1","doc":"","ref":"DNS.Message.Record.Data.AAAA.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.AAAA.t/0","doc":"","ref":"DNS.Message.Record.Data.AAAA.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.CAA","doc":"DNS CAA Record (Type 257)\n\nThe CAA (Certification Authority Authorization) record allows domain owners\nto specify which certificate authorities are authorized to issue certificates\nfor their domain.\n\nRFC 6844 defines the CAA record format:\n- Flags: 1 octet\n- Tag Length: 1 octet\n- Tag: variable length\n- Value: variable length","ref":"DNS.Message.Record.Data.CAA.html"},{"type":"function","title":"DNS.Message.Record.Data.CAA.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.CAA.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.CAA.new/1","doc":"","ref":"DNS.Message.Record.Data.CAA.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.CAA.t/0","doc":"","ref":"DNS.Message.Record.Data.CAA.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.CNAME","doc":"","ref":"DNS.Message.Record.Data.CNAME.html"},{"type":"function","title":"DNS.Message.Record.Data.CNAME.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.CNAME.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.CNAME.new/1","doc":"","ref":"DNS.Message.Record.Data.CNAME.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.CNAME.t/0","doc":"","ref":"DNS.Message.Record.Data.CNAME.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.DNSKEY","doc":"DNS DNSKEY Record (Type 48)\n\nThe DNSKEY record contains a public key used in DNSSEC to verify signatures.\nIt is used to authenticate records in DNSSEC-signed zones.\n\nRFC 4034 defines the DNSKEY record format:\n- Flags: 2 octets\n- Protocol: 1 octet (must be 3 for DNSSEC)\n- Algorithm: 1 octet\n- Public Key: variable length (base64 encoded)","ref":"DNS.Message.Record.Data.DNSKEY.html"},{"type":"function","title":"DNS.Message.Record.Data.DNSKEY.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.DNSKEY.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.DNSKEY.new/1","doc":"","ref":"DNS.Message.Record.Data.DNSKEY.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.DNSKEY.t/0","doc":"","ref":"DNS.Message.Record.Data.DNSKEY.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.DS","doc":"DNS DS Record (Type 43)\n\nThe DS (Delegation Signer) record is used in DNSSEC to establish a chain of trust\nbetween parent and child zones. It contains a hash of a DNSKEY record.\n\nRFC 4034 defines the DS record format:\n- Key Tag: 2 octets\n- Algorithm: 1 octet\n- Digest Type: 1 octet\n- Digest: variable length","ref":"DNS.Message.Record.Data.DS.html"},{"type":"function","title":"DNS.Message.Record.Data.DS.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.DS.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.DS.new/1","doc":"","ref":"DNS.Message.Record.Data.DS.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.DS.t/0","doc":"","ref":"DNS.Message.Record.Data.DS.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.HTTPS","doc":"DNS HTTPS Record (Type 65)\n\nThe HTTPS record is a specialized SVCB record for HTTPS services.\nIt has the same format as SVCB but is specifically for HTTPS endpoints.\n\nRFC 9460 defines the HTTPS record format:\n- SvcPriority: 2 octets\n- TargetName: domain name\n- SvcParams: variable length","ref":"DNS.Message.Record.Data.HTTPS.html"},{"type":"function","title":"DNS.Message.Record.Data.HTTPS.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.HTTPS.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.HTTPS.new/1","doc":"","ref":"DNS.Message.Record.Data.HTTPS.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.HTTPS.t/0","doc":"","ref":"DNS.Message.Record.Data.HTTPS.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.MX","doc":"","ref":"DNS.Message.Record.Data.MX.html"},{"type":"function","title":"DNS.Message.Record.Data.MX.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.MX.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.MX.new/1","doc":"","ref":"DNS.Message.Record.Data.MX.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.MX.t/0","doc":"","ref":"DNS.Message.Record.Data.MX.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.NS","doc":"","ref":"DNS.Message.Record.Data.NS.html"},{"type":"function","title":"DNS.Message.Record.Data.NS.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.NS.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.NS.new/1","doc":"","ref":"DNS.Message.Record.Data.NS.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.NS.t/0","doc":"","ref":"DNS.Message.Record.Data.NS.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.NSEC","doc":"","ref":"DNS.Message.Record.Data.NSEC.html"},{"type":"function","title":"DNS.Message.Record.Data.NSEC.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.NSEC.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.NSEC.new/1","doc":"","ref":"DNS.Message.Record.Data.NSEC.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.NSEC.t/0","doc":"","ref":"DNS.Message.Record.Data.NSEC.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.NSEC3","doc":"DNS NSEC3 Record (Type 50)\n\nThe NSEC3 record provides authenticated denial of existence for DNSSEC,\nusing hashed owner names instead of the original NSEC approach.\n\nRFC 5155 defines the NSEC3 record format:\n- Hash Algorithm: 1 octet\n- Flags: 1 octet\n- Iterations: 2 octets\n- Salt Length: 1 octet\n- Salt: variable length\n- Hash Length: 1 octet\n- Next Hashed Owner Name: variable length\n- Type Bit Maps: variable length","ref":"DNS.Message.Record.Data.NSEC3.html"},{"type":"function","title":"DNS.Message.Record.Data.NSEC3.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.NSEC3.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.NSEC3.new/1","doc":"","ref":"DNS.Message.Record.Data.NSEC3.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.NSEC3.t/0","doc":"","ref":"DNS.Message.Record.Data.NSEC3.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.NSEC3PARAM","doc":"DNS NSEC3PARAM Record (Type 51)\n\nThe NSEC3PARAM record provides parameters needed by authoritative servers\nto calculate hashed owner names for NSEC3 records.\n\nRFC 5155 defines the NSEC3PARAM record format:\n- Hash Algorithm: 1 octet\n- Flags: 1 octet\n- Iterations: 2 octets\n- Salt Length: 1 octet\n- Salt: variable length","ref":"DNS.Message.Record.Data.NSEC3PARAM.html"},{"type":"function","title":"DNS.Message.Record.Data.NSEC3PARAM.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.NSEC3PARAM.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.NSEC3PARAM.new/1","doc":"","ref":"DNS.Message.Record.Data.NSEC3PARAM.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.NSEC3PARAM.t/0","doc":"","ref":"DNS.Message.Record.Data.NSEC3PARAM.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.OPT","doc":"DNS OPT Record (Type 41)\n\nThe OPT pseudo-RR is used to implement EDNS0 (Extension Mechanisms for DNS).\nIt doesn't carry DNS data but contains control information for DNS transactions.\n\nRFC 6891 defines the OPT record format:\n- NAME: MUST be 0 (root domain)\n- TYPE: 41 (OPT)\n- CLASS: requestor's UDP payload size\n- TTL: extended RCODE and flags\n- RDLEN: length of all RDATA\n- RDATA: EDNS0 options","ref":"DNS.Message.Record.Data.OPT.html"},{"type":"function","title":"DNS.Message.Record.Data.OPT.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.OPT.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.OPT.new/1","doc":"","ref":"DNS.Message.Record.Data.OPT.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.OPT.t/0","doc":"","ref":"DNS.Message.Record.Data.OPT.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.PTR","doc":"","ref":"DNS.Message.Record.Data.PTR.html"},{"type":"function","title":"DNS.Message.Record.Data.PTR.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.PTR.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.PTR.new/1","doc":"","ref":"DNS.Message.Record.Data.PTR.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.PTR.t/0","doc":"","ref":"DNS.Message.Record.Data.PTR.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.RRSIG","doc":"DNS RRSIG Record (Type 46)\n\nThe RRSIG record contains a digital signature for a set of resource records\nin DNSSEC. It is used to verify the authenticity and integrity of DNS data.\n\nRFC 4034 defines the RRSIG record format:\n- Type Covered: 2 octets (RR type being signed)\n- Algorithm: 1 octet\n- Labels: 1 octet\n- Original TTL: 4 octets\n- Signature Expiration: 4 octets\n- Signature Inception: 4 octets\n- Key Tag: 2 octets\n- Signer's Name: domain name\n- Signature: variable length (base64 encoded)","ref":"DNS.Message.Record.Data.RRSIG.html"},{"type":"function","title":"DNS.Message.Record.Data.RRSIG.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.RRSIG.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.RRSIG.new/1","doc":"","ref":"DNS.Message.Record.Data.RRSIG.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.RRSIG.t/0","doc":"","ref":"DNS.Message.Record.Data.RRSIG.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.SOA","doc":"","ref":"DNS.Message.Record.Data.SOA.html"},{"type":"function","title":"DNS.Message.Record.Data.SOA.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.SOA.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.SOA.new/1","doc":"","ref":"DNS.Message.Record.Data.SOA.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.SOA.t/0","doc":"","ref":"DNS.Message.Record.Data.SOA.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.SRV","doc":"","ref":"DNS.Message.Record.Data.SRV.html"},{"type":"function","title":"DNS.Message.Record.Data.SRV.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.SRV.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.SRV.new/1","doc":"","ref":"DNS.Message.Record.Data.SRV.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.SRV.t/0","doc":"","ref":"DNS.Message.Record.Data.SRV.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.SVCB","doc":"DNS SVCB Record (Type 64)\n\nThe SVCB (Service Binding) record provides a way to publish information about\nalternative endpoints and parameters for a service, primarily for HTTPS.\n\nRFC 9460 defines the SVCB record format:\n- SvcPriority: 2 octets\n- TargetName: domain name\n- SvcParams: variable length","ref":"DNS.Message.Record.Data.SVCB.html"},{"type":"function","title":"DNS.Message.Record.Data.SVCB.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.SVCB.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.SVCB.new/1","doc":"","ref":"DNS.Message.Record.Data.SVCB.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.SVCB.t/0","doc":"","ref":"DNS.Message.Record.Data.SVCB.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.TLSA","doc":"DNS TLSA Record (Type 52)\n\nThe TLSA record is used to associate a TLS server certificate or public key\nwith the domain name where the record is found, using DNSSEC for authenticity.\n\nRFC 6698 defines the TLSA record format:\n- Usage: 1 octet\n- Selector: 1 octet\n- Matching Type: 1 octet\n- Certificate Association Data: variable length","ref":"DNS.Message.Record.Data.TLSA.html"},{"type":"function","title":"DNS.Message.Record.Data.TLSA.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.TLSA.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.TLSA.new/1","doc":"","ref":"DNS.Message.Record.Data.TLSA.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.TLSA.t/0","doc":"","ref":"DNS.Message.Record.Data.TLSA.html#t:t/0"},{"type":"module","title":"DNS.Message.Record.Data.TXT","doc":"","ref":"DNS.Message.Record.Data.TXT.html"},{"type":"function","title":"DNS.Message.Record.Data.TXT.from_iodata/2","doc":"","ref":"DNS.Message.Record.Data.TXT.html#from_iodata/2"},{"type":"function","title":"DNS.Message.Record.Data.TXT.new/1","doc":"","ref":"DNS.Message.Record.Data.TXT.html#new/1"},{"type":"type","title":"DNS.Message.Record.Data.TXT.t/0","doc":"","ref":"DNS.Message.Record.Data.TXT.html#t:t/0"},{"type":"protocol","title":"DNS.Message.RecordData","doc":"","ref":"DNS.Message.RecordData.html"},{"type":"type","title":"DNS.Message.RecordData.t/0","doc":"All the types that implement this protocol.","ref":"DNS.Message.RecordData.html#t:t/0"},{"type":"function","title":"DNS.Message.RecordData.to_iodata/1","doc":"","ref":"DNS.Message.RecordData.html#to_iodata/1"},{"type":"protocol","title":"DNS.Parameter","doc":"","ref":"DNS.Parameter.html"},{"type":"type","title":"DNS.Parameter.t/0","doc":"All the types that implement this protocol.","ref":"DNS.Parameter.html#t:t/0"},{"type":"function","title":"DNS.Parameter.to_iodata/1","doc":"","ref":"DNS.Parameter.html#to_iodata/1"},{"type":"module","title":"DNS.ResourceRecordType","doc":"# DNS RRTypes\nDNS Resource Record Type\n\n    Decimal \tHex \tRegistration Procedures \tNote\n    0\t0x0000\tRRTYPE zero is used as a special indicator for the SIG RR [RFC2931], [RFC4034] and in other circumstances and must never be allocated for ordinary use.\n    1-127\t0x0000-0x007F\tExpert Review (see mailing list information in [RFC6895]) or Standards Action\tdata TYPEs\n    128-255\t0x0080-0x00FF\tExpert Review (see mailing list information in [RFC6895]) or Standards Action\tQ TYPEs, Meta TYPEs\n    256-61439\t0x0100-0xEFFF\tExpert Review (see mailing list information in [RFC6895]) or Standards Action\tdata RRTYPEs\n    61440-65279\t0xF000-0xFEFF\tReserved for future use (IETF Review required to define use)\n    65280-65534\t0xFF00-0xFFFE\tPrivate Use\n    65535\t0xFFFF\tReserved (Standards Action)\n\n    TYPE \tValue \tMeaning \tReference \tTemplate \tRegistration Date\n    Reserved\t0\t\t[RFC6895]\t\t2021-03-08\n    A\t1\ta host address\t[RFC1035]\n    NS\t2\tan authoritative name server\t[RFC1035]\n    MD\t3\ta mail destination (OBSOLETE - use MX)\t[RFC1035]\n    MF\t4\ta mail forwarder (OBSOLETE - use MX)\t[RFC1035]\n    CNAME\t5\tthe canonical name for an alias\t[RFC1035]\n    SOA\t6\tmarks the start of a zone of authority\t[RFC1035]\n    7\ta mailbox domain name (EXPERIMENTAL)\t[RFC1035]\n    MG\t8\ta mail group member (EXPERIMENTAL)\t[RFC1035]\n    MR\t9\ta mail rename domain name (EXPERIMENTAL)\t[RFC1035]\n    NULL\t10\ta null RR (EXPERIMENTAL)\t[RFC1035]\n    WKS\t11\ta well known service description\t[RFC1035]\n    PTR\t12\ta domain name pointer\t[RFC1035]\n    HINFO\t13\thost information\t[RFC1035]\n    MINFO\t14\tmailbox or mail list information\t[RFC1035]\n    MX\t15\tmail exchange\t[RFC1035]\n    TXT\t16\ttext strings\t[RFC1035]\n    RP\t17\tfor Responsible Person\t[RFC1183]\n    AFSDB\t18\tfor AFS Data Base location\t[RFC1183][RFC5864]\n    X25\t19\tfor X.25 PSDN address\t[RFC1183]\n    ISDN\t20\tfor ISDN address\t[RFC1183]\n    RT\t21\tfor Route Through\t[RFC1183]\n    NSAP\t22\tfor NSAP address, NSAP style A record (DEPRECATED)\t[RFC1706][status-change-int-tlds-to-historic]\n    NSAP-PTR\t23\tfor domain name pointer, NSAP style (DEPRECATED)\t[RFC1706][status-change-int-tlds-to-historic]\n    SIG\t24\tfor security signature\t[RFC2536][RFC2931][RFC3110][RFC4034]\n    KEY\t25\tfor security key\t[RFC2536][RFC2539][RFC3110][RFC4034]\n    PX\t26\tX.400 mail mapping information\t[RFC2163]\n    GPOS\t27\tGeographical Position\t[RFC1712]\n    AAAA\t28\tIP6 Address\t[RFC3596]\n    LOC\t29\tLocation Information\t[RFC1876]\n    NXT\t30\tNext Domain (OBSOLETE)\t[RFC2535][RFC3755]\n    EID\t31\tEndpoint Identifier\t[Michael_Patton][http://ana-3.lcs.mit.edu/~jnc/nimrod/dns.txt]\t\t1995-06\n    NIMLOC\t32\tNimrod Locator\t[1][Michael_Patton][http://ana-3.lcs.mit.edu/~jnc/nimrod/dns.txt]\t\t1995-06\n    SRV\t33\tServer Selection\t[1][RFC2782]\n    ATMA\t34\tATM Address\t[ ATM Forum Technical Committee, \"ATM Name System, V2.0\", Doc ID: AF-DANS-0152.000, July 2000. Available from and held in escrow by IANA.]\n    NAPTR\t35\tNaming Authority Pointer\t[RFC3403]\n    KX\t36\tKey Exchanger\t[RFC2230]\n    CERT\t37\tCERT\t[RFC4398]\n    A6\t38\tA6 (OBSOLETE - use AAAA)\t[RFC2874][RFC3226][RFC6563]\n    DNAME\t39\tDNAME\t[RFC6672]\n    SINK\t40\tSINK\t[Donald_E_Eastlake][draft-eastlake-kitchen-sink]\t\t1997-11\n    OPT\t41\tOPT\t[RFC3225][RFC6891]\n    APL\t42\tAPL\t[RFC3123]\n    DS\t43\tDelegation Signer\t[RFC4034]\n    SSHFP\t44\tSSH Key Fingerprint\t[RFC4255]\n    IPSECKEY\t45\tIPSECKEY\t[RFC4025]\n    RRSIG\t46\tRRSIG\t[RFC4034]\n    NSEC\t47\tNSEC\t[RFC4034][RFC9077]\n    DNSKEY\t48\tDNSKEY\t[RFC4034]\n    DHCID\t49\tDHCID\t[RFC4701]\n    NSEC3\t50\tNSEC3\t[RFC5155][RFC9077]\n    NSEC3PARAM\t51\tNSEC3PARAM\t[RFC5155]\n    TLSA\t52\tTLSA\t[RFC6698]\n    SMIMEA\t53\tS/MIME cert association\t[RFC8162]\tSMIMEA/smimea-completed-template\t2015-12-01\n    Unassigned\t54\n    HIP\t55\tHost Identity Protocol\t[RFC8005]\n    NINFO\t56\tNINFO\t[Jim_Reid]\tNINFO/ninfo-completed-template\t2008-01-21\n    RKEY\t57\tRKEY\t[Jim_Reid]\tRKEY/rkey-completed-template\t2008-01-21\n    TALINK\t58\tTrust Anchor LINK\t[Wouter_Wijngaards]\tTALINK/talink-completed-template\t2010-02-17\n    CDS\t59\tChild DS\t[RFC7344]\tCDS/cds-completed-template\t2011-06-06\n    CDNSKEY\t60\tDNSKEY(s) the Child wants reflected in DS\t[RFC7344]\t\t2014-06-16\n    OPENPGPKEY\t61\tOpenPGP Key\t[RFC7929]\tOPENPGPKEY/openpgpkey-completed-template\t2014-08-12\n    CSYNC\t62\tChild-To-Parent Synchronization\t[RFC7477]\t\t2015-01-27\n    ZONEMD\t63\tMessage Digest Over Zone Data\t[RFC8976]\tZONEMD/zonemd-completed-template\t2018-12-12\n    SVCB\t64\tGeneral-purpose service binding\t[RFC9460]\tSVCB/svcb-completed-template\t2020-06-30\n    HTTPS\t65\tSVCB-compatible type for use with HTTP\t[RFC9460]\tHTTPS/https-completed-template\t2020-06-30\n    Unassigned\t66-98\n    SPF\t99\t\t[RFC7208]\n    UINFO\t100\t\t[IANA-Reserved]\n    UID\t101\t\t[IANA-Reserved]\n    GID\t102\t\t[IANA-Reserved]\n    UNSPEC\t103\t\t[IANA-Reserved]\n    NID\t104\t\t[RFC6742]\tILNP/nid-completed-template\n    L32\t105\t\t[RFC6742]\tILNP/l32-completed-template\n    L64\t106\t\t[RFC6742]\tILNP/l64-completed-template\n    LP\t107\t\t[RFC6742]\tILNP/lp-completed-template\n    EUI48\t108\tan EUI-48 address\t[RFC7043]\tEUI48/eui48-completed-template\t2013-03-27\n    EUI64\t109\tan EUI-64 address\t[RFC7043]\tEUI64/eui64-completed-template\t2013-03-27\n    Unassigned\t110-248\n    TKEY\t249\tTransaction Key\t[RFC2930]\n    TSIG\t250\tTransaction Signature\t[RFC8945]\n    IXFR\t251\tincremental transfer\t[RFC1995]\n    AXFR\t252\ttransfer of an entire zone\t[RFC1035][RFC5936]\n    MAILB\t253\tmailbox-related RRs (MB, MG or MR)\t[RFC1035]\n    MAILA\t254\tmail agent RRs (OBSOLETE - see MX)\t[RFC1035]\n    *\t255\tA request for some or all records the server has available\t[RFC1035][RFC6895][RFC8482]\n    URI\t256\tURI\t[RFC7553]\tURI/uri-completed-template\t2011-02-22\n    CAA\t257\tCertification Authority Restriction\t[RFC8659]\tCAA/caa-completed-template\t2011-04-07\n    AVC\t258\tApplication Visibility and Control\t[Wolfgang_Riedel]\tAVC/avc-completed-template\t2016-02-26\n    DOA\t259\tDigital Object Architecture\t[draft-durand-doa-over-dns]\tDOA/doa-completed-template\t2017-08-30\n    AMTRELAY\t260\tAutomatic Multicast Tunneling Relay\t[RFC8777]\tAMTRELAY/amtrelay-completed-template\t2019-02-06\n    RESINFO\t261\tResolver Information as Key/Value Pairs\t[draft-ietf-add-resolver-info-06]\tRESINFO/resinfo-completed-template\t2023-11-02\n    Unassigned\t262-32767\n    TA\t32768\tDNSSEC Trust Authorities\t[Sam_Weiler][http://cameo.library.cmu.edu/][ Deploying DNSSEC Without a Signed Root. Technical Report 1999-19, Information Networking Institute, Carnegie Mellon University, April 2004.]\t\t2005-12-13\n    DLV\t32769\tDNSSEC Lookaside Validation (OBSOLETE)\t[RFC8749][RFC4431]\n    Unassigned\t32770-65279\n    Private use\t65280-65534\n    Reserved\t65535\n\n# Reference\n- [iana](https://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-4)\n- [DOMAIN NAMES - IMPLEMENTATION AND SPECIFICATION](https://tools.ietf.org/html/rfc1035)\n- [Domain Name System (DNS) IANA Considerations](https://tools.ietf.org/html/rfc6895)\n- [YANG Types for DNS Classes and Resource Record Types](https://tools.ietf.org/html/rfc9108)","ref":"DNS.ResourceRecordType.html"},{"type":"function","title":"DNS.ResourceRecordType.new/1","doc":"# Create a new Class struct","ref":"DNS.ResourceRecordType.html#new/1"},{"type":"type","title":"DNS.ResourceRecordType.t/0","doc":"","ref":"DNS.ResourceRecordType.html#t:t/0"},{"type":"module","title":"DNS.Zone","doc":"DNS Zone management and operations.\n\nThis module provides the core DNS zone functionality including zone creation,\nmanagement, validation, zone file parsing, and zone transfers.","ref":"DNS.Zone.html"},{"type":"module","title":"Zone Types - DNS.Zone","doc":"The following zone types are supported:\n- `:authoritative` - Primary authoritative zone with full record management\n- `:stub` - Stub zone containing only NS records for delegation\n- `:forward` - Forward zone redirecting queries to specified servers\n- `:cache` - Cache zone for temporary DNS response caching","ref":"DNS.Zone.html#module-zone-types"},{"type":"module","title":"Creating Zones - DNS.Zone","doc":"","ref":"DNS.Zone.html#module-creating-zones"},{"type":"module","title":"Basic Zone Creation - DNS.Zone","doc":"```elixir\n# Create a basic authoritative zone\nzone = DNS.Zone.new(\"example.com\")\n\n# Create a zone with specific type\nzone = DNS.Zone.new(\"example.com\", :authoritative)\n\n# Create a zone with options\nzone = DNS.Zone.new(\"example.com\", :authoritative, soa_records: [soa_record])\n```","ref":"DNS.Zone.html#module-basic-zone-creation"},{"type":"module","title":"Interactive Zone Creation - DNS.Zone","doc":"```elixir\n# Create zone with interactive prompts\n{:ok, zone} = DNS.Zone.Editor.create_zone_interactive(\"example.com\")\n\n# Create zone with initial records\n{:ok, zone} = DNS.Zone.Editor.create_zone_interactive(\"example.com\",\n  type: :authoritative,\n  soa: [\n    mname: \"ns1.example.com\",\n    rname: \"admin.example.com\",\n    serial: 2024010101,\n    refresh: 3600,\n    retry: 1800,\n    expire: 604800,\n    minimum: 300\n  ],\n  ns: [\"ns1.example.com\", \"ns2.example.com\"],\n  a: [\"192.168.1.1\"]\n)\n```","ref":"DNS.Zone.html#module-interactive-zone-creation"},{"type":"module","title":"Managing Zone Records - DNS.Zone","doc":"","ref":"DNS.Zone.html#module-managing-zone-records"},{"type":"module","title":"Adding Records - DNS.Zone","doc":"```elixir\n# Add an A record\n{:ok, zone} = DNS.Zone.Editor.add_record(\"example.com\", :a,\n  name: \"www.example.com\",\n  ip: {192, 168, 1, 100},\n  ttl: 300\n)\n\n# Add an MX record\n{:ok, zone} = DNS.Zone.Editor.add_record(\"example.com\", :mx,\n  name: \"example.com\",\n  preference: 10,\n  exchange: \"mail.example.com\"\n)\n\n# Add a CNAME record\n{:ok, zone} = DNS.Zone.Editor.add_record(\"example.com\", :cname,\n  name: \"ftp.example.com\",\n  target: \"www.example.com\"\n)\n```","ref":"DNS.Zone.html#module-adding-records"},{"type":"module","title":"Listing and Searching Records - DNS.Zone","doc":"```elixir\n# List all records in a zone\n{:ok, records} = DNS.Zone.Editor.list_records(\"example.com\")\n\n# Search for specific records\n{:ok, a_records} = DNS.Zone.Editor.search_records(\"example.com\", type: :a)\n{:ok, www_records} = DNS.Zone.Editor.search_records(\"example.com\", name: \"www.example.com\")\n```","ref":"DNS.Zone.html#module-listing-and-searching-records"},{"type":"module","title":"Updating and Removing Records - DNS.Zone","doc":"```elixir\n# Update a record\n{:ok, zone} = DNS.Zone.Editor.update_record(\n  \"example.com\", :a,\n  [name: \"www.example.com\"],\n  [ttl: 600]\n)\n\n# Remove records\n{:ok, zone} = DNS.Zone.Editor.remove_record(\"example.com\", :a, name: \"old.example.com\")\n```","ref":"DNS.Zone.html#module-updating-and-removing-records"},{"type":"module","title":"Zone Validation - DNS.Zone","doc":"","ref":"DNS.Zone.html#module-zone-validation"},{"type":"module","title":"Basic Validation - DNS.Zone","doc":"```elixir\n# Validate a zone\ncase DNS.Zone.Validator.validate_zone(zone) do\n  {:ok, result} ->\n    IO.puts(\"Zone is valid: #{result.zone_name}\")\n  {:error, result} ->\n    IO.puts(\"Zone has errors: #{inspect(result.errors)}\")\nend\n```","ref":"DNS.Zone.html#module-basic-validation"},{"type":"module","title":"Comprehensive Diagnostics - DNS.Zone","doc":"```elixir\n# Generate zone diagnostics\ndiagnostics = DNS.Zone.Validator.generate_diagnostics(zone)\nIO.inspect(diagnostics.statistics)\nIO.inspect(diagnostics.security_assessment)\nIO.inspect(diagnostics.recommendations)\n```","ref":"DNS.Zone.html#module-comprehensive-diagnostics"},{"type":"module","title":"Zone File Operations - DNS.Zone","doc":"","ref":"DNS.Zone.html#module-zone-file-operations"},{"type":"module","title":"Parsing Zone Files - DNS.Zone","doc":"```elixir\n# Load zone from BIND format file\n{:ok, zone} = DNS.Zone.Loader.load_zone_from_file(\"example.com\", \"example.com.zone\")\n\n# Load zone from string\nzone_content = \"\"\"\n$TTL 3600\n$ORIGIN example.com.\n@ IN SOA ns1.example.com. admin.example.com. (\n    2024010101 ; serial\n    3600       ; refresh\n    1800       ; retry\n    604800     ; expire\n    300        ; minimum\n)\n@ IN NS ns1.example.com.\n@ IN NS ns2.example.com.\nwww IN A 192.168.1.100\nmail IN A 192.168.1.200\n\"\"\"\n{:ok, zone} = DNS.Zone.Loader.load_zone_from_string(zone_content)\n```","ref":"DNS.Zone.html#module-parsing-zone-files"},{"type":"module","title":"Exporting Zone Files - DNS.Zone","doc":"```elixir\n# Export to BIND format\n{:ok, bind_content} = DNS.Zone.Editor.export_zone(\"example.com\", format: :bind)\nFile.write!(\"example.com.zone\", bind_content)\n\n# Export to JSON\n{:ok, json_content} = DNS.Zone.Editor.export_zone(\"example.com\", format: :json)\nFile.write!(\"example.com.json\", json_content)\n\n# Export to YAML\n{:ok, yaml_content} = DNS.Zone.Editor.export_zone(\"example.com\", format: :yaml)\nFile.write!(\"example.com.yaml\", yaml_content)\n```","ref":"DNS.Zone.html#module-exporting-zone-files"},{"type":"module","title":"Zone Transfers - DNS.Zone","doc":"","ref":"DNS.Zone.html#module-zone-transfers"},{"type":"module","title":"Full Zone Transfer (AXFR) - DNS.Zone","doc":"```elixir\n# Perform AXFR transfer\ncase DNS.Zone.Transfer.axfr(\"example.com\") do\n  {:ok, records} ->\n    IO.puts(\"Received #{length(records)} records via AXFR\")\n  {:error, reason} ->\n    IO.puts(\"AXFR failed: #{reason}\")\nend\n```","ref":"DNS.Zone.html#module-full-zone-transfer-axfr"},{"type":"module","title":"Incremental Zone Transfer (IXFR) - DNS.Zone","doc":"```elixir\n# Perform IXFR transfer\ncase DNS.Zone.Transfer.ixfr(\"example.com\", 2024010101) do\n  {:ok, changes} ->\n    IO.puts(\"Received #{length(changes)} changes via IXFR\")\n  {:error, reason} ->\n    IO.puts(\"IXFR failed: #{reason}\")\nend\n```","ref":"DNS.Zone.html#module-incremental-zone-transfer-ixfr"},{"type":"module","title":"Applying Zone Transfers - DNS.Zone","doc":"```elixir\n# Apply transferred zone data\nrecords = [...] # Records from AXFR/IXFR\ncase DNS.Zone.Transfer.apply_transfer(\"example.com\", records, transfer_type: :axfr) do\n  {:ok, zone} ->\n    IO.puts(\"Zone updated successfully\")\n  {:error, reason} ->\n    IO.puts(\"Failed to apply transfer: #{reason}\")\nend\n```","ref":"DNS.Zone.html#module-applying-zone-transfers"},{"type":"module","title":"DNSSEC Management - DNS.Zone","doc":"","ref":"DNS.Zone.html#module-dnssec-management"},{"type":"module","title":"Enabling DNSSEC - DNS.Zone","doc":"```elixir\n# Enable DNSSEC for a zone\ncase DNS.Zone.Editor.enable_dnssec(\"example.com\") do\n  {:ok, signed_zone} ->\n    IO.puts(\"DNSSEC enabled successfully\")\n  {:error, reason} ->\n    IO.puts(\"DNSSEC setup failed: #{reason}\")\nend\n```","ref":"DNS.Zone.html#module-enabling-dnssec"},{"type":"module","title":"Manual DNSSEC Signing - DNS.Zone","doc":"```elixir\n# Sign zone with custom options\ncase DNS.Zone.DNSSEC.sign_zone(zone,\n  algorithm: :rsasha256,\n  key_size: 2048,\n  nsec3_enabled: true\n) do\n  {:ok, signed_zone} ->\n    IO.puts(\"Zone signed successfully\")\n  {:error, reason} ->\n    IO.puts(\"Signing failed: #{reason}\")\nend\n```","ref":"DNS.Zone.html#module-manual-dnssec-signing"},{"type":"module","title":"Zone Cloning - DNS.Zone","doc":"","ref":"DNS.Zone.html#module-zone-cloning"},{"type":"module","title":"Clone Zone for Testing - DNS.Zone","doc":"```elixir\n# Clone an existing zone\ncase DNS.Zone.Editor.clone_zone(\"production.com\", \"staging.com\") do\n  {:ok, cloned_zone} ->\n    IO.puts(\"Zone cloned successfully\")\n  {:error, reason} ->\n    IO.puts(\"Cloning failed: #{reason}\")\nend\n```","ref":"DNS.Zone.html#module-clone-zone-for-testing"},{"type":"module","title":"Examples - DNS.Zone","doc":"","ref":"DNS.Zone.html#module-examples"},{"type":"module","title":"Complete Zone Setup - DNS.Zone","doc":"```elixir\n# Create a complete zone with all essential records\n{:ok, zone} = DNS.Zone.Editor.create_zone_interactive(\"company.com\",\n  type: :authoritative,\n  soa: [\n    mname: \"ns1.company.com\",\n    rname: \"admin.company.com\",\n    serial: 2024010101,\n    refresh: 3600,\n    retry: 1800,\n    expire: 604800,\n    minimum: 300\n  ],\n  ns: [\"ns1.company.com\", \"ns2.company.com\"],\n  a: [\n    {\"@\", \"192.168.1.10\"},\n    {\"www\", \"192.168.1.10\"},\n    {\"mail\", \"192.168.1.20\"},\n    {\"ns1\", \"192.168.1.1\"},\n    {\"ns2\", \"192.168.1.2\"}\n  ],\n  mx: [{10, \"mail.company.com\"}],\n  txt: [{\"@\", \"v=spf1 mx ~all\"}]\n)\n\n# Validate the zone\n{:ok, validation} = DNS.Zone.Validator.validate_zone(zone)\nIO.inspect(validation.summary)\n\n# Export to BIND format\n{:ok, zone_file} = DNS.Zone.Editor.export_zone(\"company.com\", format: :bind)\nFile.write!(\"company.com.zone\", zone_file)\n```","ref":"DNS.Zone.html#module-complete-zone-setup"},{"type":"function","title":"DNS.Zone.hostname/2","doc":"","ref":"DNS.Zone.html#hostname/2"},{"type":"function","title":"DNS.Zone.new/3","doc":"","ref":"DNS.Zone.html#new/3"},{"type":"type","title":"DNS.Zone.t/0","doc":"","ref":"DNS.Zone.html#t:t/0"},{"type":"type","title":"DNS.Zone.zone_type/0","doc":"","ref":"DNS.Zone.html#t:zone_type/0"},{"type":"module","title":"DNS.Zone.Cache","doc":"Zone caching system for DNS zones.\n\nProvides in-memory caching for zone data with TTL-based expiration,\nautomatic refresh, and memory management.","ref":"DNS.Zone.Cache.html"},{"type":"function","title":"DNS.Zone.Cache.cleanup_expired/0","doc":"Clean expired zones from cache.","ref":"DNS.Zone.Cache.html#cleanup_expired/0"},{"type":"function","title":"DNS.Zone.Cache.clear/0","doc":"Clear the entire cache.","ref":"DNS.Zone.Cache.html#clear/0"},{"type":"function","title":"DNS.Zone.Cache.delete_zone/1","doc":"Remove a zone from cache.","ref":"DNS.Zone.Cache.html#delete_zone/1"},{"type":"function","title":"DNS.Zone.Cache.get_zone/1","doc":"Get a zone from cache if not expired.","ref":"DNS.Zone.Cache.html#get_zone/1"},{"type":"function","title":"DNS.Zone.Cache.get_zone_meta/1","doc":"Get cache metadata for a zone.","ref":"DNS.Zone.Cache.html#get_zone_meta/1"},{"type":"function","title":"DNS.Zone.Cache.init/0","doc":"Initialize the zone cache.","ref":"DNS.Zone.Cache.html#init/0"},{"type":"function","title":"DNS.Zone.Cache.list_zones/0","doc":"Get all cached zones that are not expired.","ref":"DNS.Zone.Cache.html#list_zones/0"},{"type":"function","title":"DNS.Zone.Cache.put_zone/3","doc":"Store a zone in cache with TTL.","ref":"DNS.Zone.Cache.html#put_zone/3"},{"type":"function","title":"DNS.Zone.Cache.refresh_zone/1","doc":"Refresh a zone from its source if needed.","ref":"DNS.Zone.Cache.html#refresh_zone/1"},{"type":"function","title":"DNS.Zone.Cache.stats/0","doc":"Get cache statistics.","ref":"DNS.Zone.Cache.html#stats/0"},{"type":"function","title":"DNS.Zone.Cache.zone_cached?/1","doc":"Check if a zone is cached and not expired.","ref":"DNS.Zone.Cache.html#zone_cached?/1"},{"type":"module","title":"DNS.Zone.DNSSEC","doc":"DNSSEC zone signing and validation functionality.\n\nProvides DNSSEC zone signing, key management, and record generation\naccording to DNSSEC standards (RFC 4034, RFC 4035, RFC 4509).","ref":"DNS.Zone.DNSSEC.html"},{"type":"function","title":"DNS.Zone.DNSSEC.calculate_key_tag/1","doc":"Calculate key tag for DNSKEY record.","ref":"DNS.Zone.DNSSEC.html#calculate_key_tag/1"},{"type":"function","title":"DNS.Zone.DNSSEC.generate_dnskey/2","doc":"Generate DNSKEY record for a DNSSEC zone.","ref":"DNS.Zone.DNSSEC.html#generate_dnskey/2"},{"type":"function","title":"DNS.Zone.DNSSEC.generate_ds/3","doc":"Generate DS record for a DNSKEY.","ref":"DNS.Zone.DNSSEC.html#generate_ds/3"},{"type":"function","title":"DNS.Zone.DNSSEC.generate_key_pair/1","doc":"Generate key pair for DNSSEC.","ref":"DNS.Zone.DNSSEC.html#generate_key_pair/1"},{"type":"function","title":"DNS.Zone.DNSSEC.generate_nsec3/3","doc":"Generate NSEC3 record for denial of existence with hashed names.","ref":"DNS.Zone.DNSSEC.html#generate_nsec3/3"},{"type":"function","title":"DNS.Zone.DNSSEC.generate_nsec/3","doc":"Generate NSEC record for denial of existence.","ref":"DNS.Zone.DNSSEC.html#generate_nsec/3"},{"type":"function","title":"DNS.Zone.DNSSEC.generate_rrsig/3","doc":"Generate RRSIG record for a set of records.","ref":"DNS.Zone.DNSSEC.html#generate_rrsig/3"},{"type":"function","title":"DNS.Zone.DNSSEC.sign_zone/2","doc":"Sign a complete zone with DNSSEC records.","ref":"DNS.Zone.DNSSEC.html#sign_zone/2"},{"type":"function","title":"DNS.Zone.DNSSEC.validate_zone/1","doc":"Validate DNSSEC signatures for a zone.","ref":"DNS.Zone.DNSSEC.html#validate_zone/1"},{"type":"module","title":"DNS.Zone.Editor","doc":"Zone editor interface for interactive zone management.\n\nProvides a high-level interface for zone creation, modification, and management\nwith built-in validation and error handling.","ref":"DNS.Zone.Editor.html"},{"type":"function","title":"DNS.Zone.Editor.add_record/3","doc":"Add a record to a zone.","ref":"DNS.Zone.Editor.html#add_record/3"},{"type":"function","title":"DNS.Zone.Editor.clone_zone/2","doc":"Clone a zone for testing purposes.","ref":"DNS.Zone.Editor.html#clone_zone/2"},{"type":"function","title":"DNS.Zone.Editor.create_zone_interactive/2","doc":"Create a new zone with interactive prompts.","ref":"DNS.Zone.Editor.html#create_zone_interactive/2"},{"type":"function","title":"DNS.Zone.Editor.enable_dnssec/2","doc":"Enable DNSSEC for a zone.","ref":"DNS.Zone.Editor.html#enable_dnssec/2"},{"type":"function","title":"DNS.Zone.Editor.export_zone/2","doc":"Export zone to standard format.","ref":"DNS.Zone.Editor.html#export_zone/2"},{"type":"function","title":"DNS.Zone.Editor.list_records/1","doc":"List all records in a zone.","ref":"DNS.Zone.Editor.html#list_records/1"},{"type":"function","title":"DNS.Zone.Editor.remove_record/3","doc":"Remove a record from a zone.","ref":"DNS.Zone.Editor.html#remove_record/3"},{"type":"function","title":"DNS.Zone.Editor.search_records/2","doc":"Search for records by name, type, or value.","ref":"DNS.Zone.Editor.html#search_records/2"},{"type":"function","title":"DNS.Zone.Editor.update_record/4","doc":"Update an existing record in a zone.","ref":"DNS.Zone.Editor.html#update_record/4"},{"type":"function","title":"DNS.Zone.Editor.validate_zone/1","doc":"Validate a zone and provide feedback.","ref":"DNS.Zone.Editor.html#validate_zone/1"},{"type":"module","title":"DNS.Zone.FileParser","doc":"DNS Zone file parser and generator for standard BIND format zone files.\n\nSupports parsing and generation of DNS record types including:\n- Standard records: SOA, NS, A, AAAA, CNAME, MX, TXT, SRV, PTR\n- DNSSEC records: DNSKEY, DS, RRSIG, NSEC, NSEC3, NSEC3PARAM\n- Security records: CAA, TLSA\n- Modern records: HTTPS, SVCB\n\nHandles:\n- Comments (starting with ;)\n- Line continuations\n- Zone directives: $ORIGIN, $TTL, $INCLUDE, $GENERATE\n- Class specifications (IN, CH, HS, NONE, ANY)\n- TTL specifications and defaults\n- Zone validation and error reporting","ref":"DNS.Zone.FileParser.html"},{"type":"function","title":"DNS.Zone.FileParser.generate/1","doc":"Generate a zone file string from zone data.","ref":"DNS.Zone.FileParser.html#generate/1"},{"type":"function","title":"DNS.Zone.FileParser.parse/1","doc":"Parse a zone file from a string with enhanced error handling and validation.","ref":"DNS.Zone.FileParser.html#parse/1"},{"type":"function","title":"Examples - DNS.Zone.FileParser.parse/1","doc":"iex> zone_content = \"\"\"\n    ...> $ORIGIN example.com.\n    ...> $TTL 3600\n    ...> @       IN  SOA ns1.example.com. admin.example.com. (\n    ...>                     2024010101  ; Serial\n    ...>                     3600        ; Refresh\n    ...>                     1800        ; Retry\n    ...>                     604800      ; Expire\n    ...>                     86400 )     ; Minimum TTL\n    ...> @       IN  NS  ns1.example.com.\n    ...> @       IN  NS  ns2.example.com.\n    ...> ns1     IN  A   192.0.2.1\n    ...> ns2     IN  A   192.0.2.2\n    ...> www     IN  A   192.0.2.100\n    ...> \"\"\"\n    iex> {:ok, zone} = DNS.Zone.FileParser.parse(zone_content)\n    iex> length(zone.records)\n    5\n    iex> zone.origin\n    \"example.com\"","ref":"DNS.Zone.FileParser.html#parse/1-examples"},{"type":"type","title":"DNS.Zone.FileParser.parse_error/0","doc":"","ref":"DNS.Zone.FileParser.html#t:parse_error/0"},{"type":"function","title":"DNS.Zone.FileParser.parse_file/1","doc":"Parse a zone file from a file path with enhanced error handling.","ref":"DNS.Zone.FileParser.html#parse_file/1"},{"type":"type","title":"DNS.Zone.FileParser.parse_warning/0","doc":"","ref":"DNS.Zone.FileParser.html#t:parse_warning/0"},{"type":"function","title":"DNS.Zone.FileParser.parse_with_context/2","doc":"Parse a zone file from a string with detailed error reporting.","ref":"DNS.Zone.FileParser.html#parse_with_context/2"},{"type":"function","title":"DNS.Zone.FileParser.validate_zone/1","doc":"Validate zone data for common issues.","ref":"DNS.Zone.FileParser.html#validate_zone/1"},{"type":"type","title":"DNS.Zone.FileParser.zone_data/0","doc":"","ref":"DNS.Zone.FileParser.html#t:zone_data/0"},{"type":"module","title":"DNS.Zone.Loader","doc":"Zone loading and persistence system.\n\nHandles loading zones from files, databases, and other sources,\nas well as saving zones back to persistent storage.","ref":"DNS.Zone.Loader.html"},{"type":"function","title":"DNS.Zone.Loader.create_zone_data/1","doc":"Create zone data from zone options.","ref":"DNS.Zone.Loader.html#create_zone_data/1"},{"type":"function","title":"DNS.Zone.Loader.load_zone_from_file/2","doc":"Load a single zone from file.","ref":"DNS.Zone.Loader.html#load_zone_from_file/2"},{"type":"function","title":"DNS.Zone.Loader.load_zones_from_directory/1","doc":"Load zones from a directory containing zone files.","ref":"DNS.Zone.Loader.html#load_zones_from_directory/1"},{"type":"function","title":"DNS.Zone.Loader.reload_zone/1","doc":"Reload a zone from its source file.","ref":"DNS.Zone.Loader.html#reload_zone/1"},{"type":"function","title":"DNS.Zone.Loader.save_zone_to_file/2","doc":"Save a zone to file.","ref":"DNS.Zone.Loader.html#save_zone_to_file/2"},{"type":"module","title":"DNS.Zone.Manager","doc":"Zone management system for DNS zones.\n\nProvides CRUD operations for zone management, zone lifecycle operations,\nand zone coordination across the DNS system.","ref":"DNS.Zone.Manager.html"},{"type":"function","title":"DNS.Zone.Manager.create_zone/3","doc":"Create a new zone with basic configuration.","ref":"DNS.Zone.Manager.html#create_zone/3"},{"type":"function","title":"DNS.Zone.Manager.delete_zone/1","doc":"Delete a zone.","ref":"DNS.Zone.Manager.html#delete_zone/1"},{"type":"function","title":"DNS.Zone.Manager.get_zone/1","doc":"Get a zone by name.","ref":"DNS.Zone.Manager.html#get_zone/1"},{"type":"function","title":"DNS.Zone.Manager.init/0","doc":"Initialize the zone management system.\n\nThis function initializes the zone store and clears any existing zones.\nIt is primarily used for testing to ensure a clean state.","ref":"DNS.Zone.Manager.html#init/0"},{"type":"function","title":"DNS.Zone.Manager.list_zones/0","doc":"List all zones.","ref":"DNS.Zone.Manager.html#list_zones/0"},{"type":"function","title":"DNS.Zone.Manager.load_zone_from_file/2","doc":"Load a zone from a file.","ref":"DNS.Zone.Manager.html#load_zone_from_file/2"},{"type":"function","title":"DNS.Zone.Manager.load_zone_from_string/2","doc":"Load a zone from string content.","ref":"DNS.Zone.Manager.html#load_zone_from_string/2"},{"type":"function","title":"DNS.Zone.Manager.reload_zone/1","doc":"Reload a zone from its source file.","ref":"DNS.Zone.Manager.html#reload_zone/1"},{"type":"function","title":"DNS.Zone.Manager.update_zone/2","doc":"Update zone configuration.","ref":"DNS.Zone.Manager.html#update_zone/2"},{"type":"function","title":"DNS.Zone.Manager.validate_zone/1","doc":"Validate zone configuration.","ref":"DNS.Zone.Manager.html#validate_zone/1"},{"type":"type","title":"DNS.Zone.Manager.zone_data/0","doc":"","ref":"DNS.Zone.Manager.html#t:zone_data/0"},{"type":"type","title":"DNS.Zone.Manager.zone_name/0","doc":"","ref":"DNS.Zone.Manager.html#t:zone_name/0"},{"type":"type","title":"DNS.Zone.Manager.zone_type/0","doc":"","ref":"DNS.Zone.Manager.html#t:zone_type/0"},{"type":"module","title":"DNS.Zone.Name","doc":"# DNS Zone Name","ref":"DNS.Zone.Name.html"},{"type":"function","title":"DNS.Zone.Name.child?/2","doc":"Check if the name1 is a child of name2.","ref":"DNS.Zone.Name.html#child?/2"},{"type":"function","title":"DNS.Zone.Name.from_domain/1","doc":"","ref":"DNS.Zone.Name.html#from_domain/1"},{"type":"function","title":"DNS.Zone.Name.match_domain/2","doc":"","ref":"DNS.Zone.Name.html#match_domain/2"},{"type":"function","title":"DNS.Zone.Name.new/1","doc":"","ref":"DNS.Zone.Name.html#new/1"},{"type":"type","title":"DNS.Zone.Name.t/0","doc":"","ref":"DNS.Zone.Name.html#t:t/0"},{"type":"module","title":"DNS.Zone.RRSet","doc":"DNS Resource Record Set","ref":"DNS.Zone.RRSet.html"},{"type":"function","title":"DNS.Zone.RRSet.new/4","doc":"","ref":"DNS.Zone.RRSet.html#new/4"},{"type":"type","title":"DNS.Zone.RRSet.t/0","doc":"","ref":"DNS.Zone.RRSet.html#t:t/0"},{"type":"module","title":"DNS.Zone.Recursive","doc":"DNS Zone Recursive","ref":"DNS.Zone.Recursive.html"},{"type":"function","title":"DNS.Zone.Recursive.resolve/2","doc":"","ref":"DNS.Zone.Recursive.html#resolve/2"},{"type":"function","title":"DNS.Zone.Recursive.root_ns_addrs/1","doc":"","ref":"DNS.Zone.Recursive.html#root_ns_addrs/1"},{"type":"module","title":"DNS.Zone.RootHint","doc":"DNS Root Hint\n\nRoot Servers\n\nThe authoritative name servers that serve the DNS root zone, commonly known as the “root servers”, are a network of hundreds of servers in many countries around the world. They are configured in the DNS root zone as 13 named authorities, as follows.\n\nList of Root Servers\n\nHostname | IP Addresses | Operator\na.root-servers.net | 198.41.0.4, 2001:503:ba3e::2:30 | Verisign, Inc.\nb.root-servers.net | 170.247.170.2, 2801:1b8:10::b | University of Southern California, Information Sciences Institute\nc.root-servers.net | 192.33.4.12, 2001:500:2::c | Cogent Communications\nd.root-servers.net | 199.7.91.13, 2001:500:2d::d | University of Maryland\ne.root-servers.net | 192.203.230.10, 2001:500:a8::e | NASA (Ames Research Center)\nf.root-servers.net | 192.5.5.241, 2001:500:2f::f | Internet Systems Consortium, Inc.\ng.root-servers.net | 192.112.36.4, 2001:500:12::d0d | US Department of Defense (NIC)\nh.root-servers.net | 198.97.190.53, 2001:500:1::53 | US Army (Research Lab)\ni.root-servers.net | 192.36.148.17, 2001:7fe::53 | Netnod\nj.root-servers.net | 192.58.128.30, 2001:503:c27::2:30 | Verisign, Inc.\nk.root-servers.net | 193.0.14.129, 2001:7fd::1 | RIPE NCC\nl.root-servers.net | 199.7.83.42, 2001:500:9f::42 | ICANN\nm.root-servers.net | 202.12.27.33, 2001:dc3::35 | WIDE Project","ref":"DNS.Zone.RootHint.html"},{"type":"function","title":"DNS.Zone.RootHint.data_dir/0","doc":"","ref":"DNS.Zone.RootHint.html#data_dir/0"},{"type":"function","title":"DNS.Zone.RootHint.links/0","doc":"","ref":"DNS.Zone.RootHint.html#links/0"},{"type":"function","title":"DNS.Zone.RootHint.nameservers/0","doc":"","ref":"DNS.Zone.RootHint.html#nameservers/0"},{"type":"function","title":"DNS.Zone.RootHint.root_hints/0","doc":"","ref":"DNS.Zone.RootHint.html#root_hints/0"},{"type":"function","title":"DNS.Zone.RootHint.root_hints_text/0","doc":"","ref":"DNS.Zone.RootHint.html#root_hints_text/0"},{"type":"module","title":"DNS.Zone.Store","doc":"Zone storage system for managing DNS zones in memory.\n\nProvides ETS-based storage for zone management with optional persistence.","ref":"DNS.Zone.Store.html"},{"type":"function","title":"DNS.Zone.Store.clear/0","doc":"Clear all zones.","ref":"DNS.Zone.Store.html#clear/0"},{"type":"function","title":"DNS.Zone.Store.delete_zone/1","doc":"Delete a zone.","ref":"DNS.Zone.Store.html#delete_zone/1"},{"type":"function","title":"DNS.Zone.Store.ensure_initialized/0","doc":"Ensure the zone store is initialized.","ref":"DNS.Zone.Store.html#ensure_initialized/0"},{"type":"function","title":"DNS.Zone.Store.get_zone/1","doc":"Get a zone by name.","ref":"DNS.Zone.Store.html#get_zone/1"},{"type":"function","title":"DNS.Zone.Store.get_zones_by_type/1","doc":"Get zones by type.","ref":"DNS.Zone.Store.html#get_zones_by_type/1"},{"type":"function","title":"DNS.Zone.Store.init/0","doc":"Initialize the zone store.","ref":"DNS.Zone.Store.html#init/0"},{"type":"function","title":"DNS.Zone.Store.list_zones/0","doc":"List all zones.","ref":"DNS.Zone.Store.html#list_zones/0"},{"type":"function","title":"DNS.Zone.Store.put_zone/1","doc":"Store a zone.","ref":"DNS.Zone.Store.html#put_zone/1"},{"type":"function","title":"DNS.Zone.Store.zone_exists?/1","doc":"Check if a zone exists.","ref":"DNS.Zone.Store.html#zone_exists?/1"},{"type":"module","title":"DNS.Zone.Transfer","doc":"Zone transfer functionality for DNS zones (AXFR/IXFR).\n\nProvides full zone transfer (AXFR) and incremental zone transfer (IXFR)\ncapabilities according to RFC 1995 and RFC 5936.","ref":"DNS.Zone.Transfer.html"},{"type":"function","title":"DNS.Zone.Transfer.apply_transfer/3","doc":"Apply transferred zone data to local zone store.","ref":"DNS.Zone.Transfer.html#apply_transfer/3"},{"type":"function","title":"DNS.Zone.Transfer.axfr/1","doc":"Perform full zone transfer (AXFR) for a zone.","ref":"DNS.Zone.Transfer.html#axfr/1"},{"type":"function","title":"DNS.Zone.Transfer.create_transfer_request/3","doc":"Create zone transfer request.","ref":"DNS.Zone.Transfer.html#create_transfer_request/3"},{"type":"function","title":"DNS.Zone.Transfer.create_transfer_response/3","doc":"Create zone transfer response message.","ref":"DNS.Zone.Transfer.html#create_transfer_response/3"},{"type":"function","title":"DNS.Zone.Transfer.ixfr/2","doc":"Perform incremental zone transfer (IXFR) for a zone.","ref":"DNS.Zone.Transfer.html#ixfr/2"},{"type":"function","title":"DNS.Zone.Transfer.transfer_allowed?/2","doc":"Validate if zone transfer is allowed for the requesting client.","ref":"DNS.Zone.Transfer.html#transfer_allowed?/2"},{"type":"module","title":"DNS.Zone.Validator","doc":"Zone validation and diagnostics tools for DNS zones.\n\nProvides comprehensive validation for zone syntax, semantics,\nDNSSEC compliance, and RFC compliance checking.","ref":"DNS.Zone.Validator.html"},{"type":"function","title":"DNS.Zone.Validator.generate_diagnostics/1","doc":"Generate zone diagnostics report.","ref":"DNS.Zone.Validator.html#generate_diagnostics/1"},{"type":"function","title":"DNS.Zone.Validator.generate_performance_metrics/1","doc":"Generate performance metrics for the zone.","ref":"DNS.Zone.Validator.html#generate_performance_metrics/1"},{"type":"function","title":"DNS.Zone.Validator.generate_recommendations/1","doc":"Generate recommendations for zone optimization.","ref":"DNS.Zone.Validator.html#generate_recommendations/1"},{"type":"function","title":"DNS.Zone.Validator.generate_security_assessment/1","doc":"Generate security assessment for the zone.","ref":"DNS.Zone.Validator.html#generate_security_assessment/1"},{"type":"function","title":"DNS.Zone.Validator.generate_statistics/1","doc":"Generate zone statistics.","ref":"DNS.Zone.Validator.html#generate_statistics/1"},{"type":"function","title":"DNS.Zone.Validator.validate_dnssec_records/1","doc":"Validate DNSSEC records and signatures.","ref":"DNS.Zone.Validator.html#validate_dnssec_records/1"},{"type":"function","title":"DNS.Zone.Validator.validate_ns_records/1","doc":"Validate NS records and delegation.","ref":"DNS.Zone.Validator.html#validate_ns_records/1"},{"type":"function","title":"DNS.Zone.Validator.validate_record_consistency/1","doc":"Validate record consistency and conflicts.","ref":"DNS.Zone.Validator.html#validate_record_consistency/1"},{"type":"function","title":"DNS.Zone.Validator.validate_soa_record/1","doc":"Validate SOA record format and values.","ref":"DNS.Zone.Validator.html#validate_soa_record/1"},{"type":"function","title":"DNS.Zone.Validator.validate_ttl_values/1","doc":"Validate TTL values across the zone.","ref":"DNS.Zone.Validator.html#validate_ttl_values/1"},{"type":"function","title":"DNS.Zone.Validator.validate_zone/1","doc":"Validate a complete zone for RFC compliance and best practices.","ref":"DNS.Zone.Validator.html#validate_zone/1"},{"type":"function","title":"DNS.Zone.Validator.validate_zone_structure/1","doc":"Validate zone structure and required records.","ref":"DNS.Zone.Validator.html#validate_zone_structure/1"},{"type":"task","title":"mix dns.fetch_root","doc":"Fetch Root data from [iana]( https://data.iana.org/)","ref":"Mix.Tasks.Dns.FetchRoot.html"},{"type":"function","title":"Mix.Tasks.Dns.FetchRoot.run/1","doc":"","ref":"Mix.Tasks.Dns.FetchRoot.html#run/1"},{"type":"extras","title":"DNS","doc":"# DNS\n\n[![release](https://github.com/gsmlg-dev/ex_dns/actions/workflows/release.yml/badge.svg)](https://github.com/gsmlg-dev/ex_dns/actions/workflows/release.yml) \n[![Hex.pm](https://img.shields.io/hexpm/v/ex_dns.svg)](https://hex.pm/packages/ex_dns) \n[![Documentation](https://img.shields.io/badge/documentation-gray)](https://hexdocs.pm/ex_dns)\n\n---","ref":"readme.html"},{"type":"extras","title":"Installation - DNS","doc":"The package can be installed by adding `ex_dns` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_dns, \"~> 0.4.0\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"content_type":"text/markdown","proglang":"elixir","producer":{"name":"ex_doc","version":"0.37.2"}}